"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import sys
import typing
import yandex.cloud.connectionmanager.v1.common_pb2

if sys.version_info >= (3, 10):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class OpenSearchAuth(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    USER_PASSWORD_FIELD_NUMBER: builtins.int
    @property
    def user_password(self) -> yandex.cloud.connectionmanager.v1.common_pb2.UserPasswordAuth: ...
    def __init__(
        self,
        *,
        user_password: yandex.cloud.connectionmanager.v1.common_pb2.UserPasswordAuth | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["security", b"security", "user_password", b"user_password"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["security", b"security", "user_password", b"user_password"]) -> None: ...
    def WhichOneof(self, oneof_group: typing.Literal["security", b"security"]) -> typing.Literal["user_password"] | None: ...

global___OpenSearchAuth = OpenSearchAuth

@typing.final
class OpenSearchCluster(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing.final
    class Host(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        class _GroupRole:
            ValueType = typing.NewType("ValueType", builtins.int)
            V: typing_extensions.TypeAlias = ValueType

        class _GroupRoleEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[OpenSearchCluster.Host._GroupRole.ValueType], builtins.type):
            DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
            GROUP_ROLE_UNSPECIFIED: OpenSearchCluster.Host._GroupRole.ValueType  # 0
            DATA: OpenSearchCluster.Host._GroupRole.ValueType  # 1
            MANAGER: OpenSearchCluster.Host._GroupRole.ValueType  # 2

        class GroupRole(_GroupRole, metaclass=_GroupRoleEnumTypeWrapper): ...
        GROUP_ROLE_UNSPECIFIED: OpenSearchCluster.Host.GroupRole.ValueType  # 0
        DATA: OpenSearchCluster.Host.GroupRole.ValueType  # 1
        MANAGER: OpenSearchCluster.Host.GroupRole.ValueType  # 2

        class _Health:
            ValueType = typing.NewType("ValueType", builtins.int)
            V: typing_extensions.TypeAlias = ValueType

        class _HealthEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[OpenSearchCluster.Host._Health.ValueType], builtins.type):
            DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
            HEALTH_UNSPECIFIED: OpenSearchCluster.Host._Health.ValueType  # 0
            ALIVE: OpenSearchCluster.Host._Health.ValueType  # 1
            DEAD: OpenSearchCluster.Host._Health.ValueType  # 2
            DEGRADED: OpenSearchCluster.Host._Health.ValueType  # 3
            READONLY: OpenSearchCluster.Host._Health.ValueType  # 4

        class Health(_Health, metaclass=_HealthEnumTypeWrapper): ...
        HEALTH_UNSPECIFIED: OpenSearchCluster.Host.Health.ValueType  # 0
        ALIVE: OpenSearchCluster.Host.Health.ValueType  # 1
        DEAD: OpenSearchCluster.Host.Health.ValueType  # 2
        DEGRADED: OpenSearchCluster.Host.Health.ValueType  # 3
        READONLY: OpenSearchCluster.Host.Health.ValueType  # 4

        HOST_FIELD_NUMBER: builtins.int
        PORT_FIELD_NUMBER: builtins.int
        HEALTH_FIELD_NUMBER: builtins.int
        ROLES_FIELD_NUMBER: builtins.int
        host: builtins.str
        port: builtins.int
        health: global___OpenSearchCluster.Host.Health.ValueType
        @property
        def roles(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[global___OpenSearchCluster.Host.GroupRole.ValueType]: ...
        def __init__(
            self,
            *,
            host: builtins.str = ...,
            port: builtins.int = ...,
            health: global___OpenSearchCluster.Host.Health.ValueType = ...,
            roles: collections.abc.Iterable[global___OpenSearchCluster.Host.GroupRole.ValueType] | None = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing.Literal["health", b"health", "host", b"host", "port", b"port", "roles", b"roles"]) -> None: ...

    HOSTS_FIELD_NUMBER: builtins.int
    TLS_PARAMS_FIELD_NUMBER: builtins.int
    @property
    def hosts(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___OpenSearchCluster.Host]: ...
    @property
    def tls_params(self) -> yandex.cloud.connectionmanager.v1.common_pb2.TLSParams: ...
    def __init__(
        self,
        *,
        hosts: collections.abc.Iterable[global___OpenSearchCluster.Host] | None = ...,
        tls_params: yandex.cloud.connectionmanager.v1.common_pb2.TLSParams | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["tls_params", b"tls_params"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["hosts", b"hosts", "tls_params", b"tls_params"]) -> None: ...

global___OpenSearchCluster = OpenSearchCluster

@typing.final
class OpenSearchConnection(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CLUSTER_FIELD_NUMBER: builtins.int
    MANAGED_CLUSTER_ID_FIELD_NUMBER: builtins.int
    AUTH_FIELD_NUMBER: builtins.int
    managed_cluster_id: builtins.str
    """When creating/updating Connection, the field "managed_cluster_id" is
    mutually exclusive with "cluster".
    """
    @property
    def cluster(self) -> global___OpenSearchCluster:
        """When creating/updating Connection, the field "cluster" is mutually
        exclusive with "managed_cluster_id".
        """

    @property
    def auth(self) -> global___OpenSearchAuth: ...
    def __init__(
        self,
        *,
        cluster: global___OpenSearchCluster | None = ...,
        managed_cluster_id: builtins.str = ...,
        auth: global___OpenSearchAuth | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["auth", b"auth", "cluster", b"cluster"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["auth", b"auth", "cluster", b"cluster", "managed_cluster_id", b"managed_cluster_id"]) -> None: ...

global___OpenSearchConnection = OpenSearchConnection



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import google.protobuf.descriptor
import google.protobuf.message
import typing

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class InitRequest(google.protobuf.message.Message):
    """Request to initialize and check version."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TOOL_NAME_FIELD_NUMBER: builtins.int
    VERSION_FIELD_NUMBER: builtins.int
    tool_name: builtins.str
    """Tool name to check."""
    version: builtins.str
    """Version to check."""
    def __init__(
        self,
        *,
        tool_name: builtins.str = ...,
        version: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["tool_name", b"tool_name", "version", b"version"]) -> None: ...

global___InitRequest = InitRequest

@typing.final
class InitResponse(google.protobuf.message.Message):
    """Response for initialization.
    Blocked versions return FAILED_PRECONDITION error instead.
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing.final
    class DeprecationWarning(google.protobuf.message.Message):
        """Warning details for versions being phased out."""

        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        REASON_FIELD_NUMBER: builtins.int
        reason: builtins.str
        """Reason why the version is being phased out."""
        def __init__(
            self,
            *,
            reason: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing.Literal["reason", b"reason"]) -> None: ...

    DEPRECATION_WARNING_FIELD_NUMBER: builtins.int
    @property
    def deprecation_warning(self) -> global___InitResponse.DeprecationWarning:
        """Warning information for versions being phased out."""

    def __init__(
        self,
        *,
        deprecation_warning: global___InitResponse.DeprecationWarning | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["deprecation_warning", b"deprecation_warning"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["deprecation_warning", b"deprecation_warning"]) -> None: ...

global___InitResponse = InitResponse



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import abc
import collections.abc
import grpc
import grpc.aio
import typing
import yandex.cloud.operation.operation_pb2
import yandex.cloud.organizationmanager.v1.idp.synchronization_session_service_pb2

_T = typing.TypeVar("_T")

class _MaybeAsyncIterator(collections.abc.AsyncIterator[_T], collections.abc.Iterator[_T], metaclass=abc.ABCMeta): ...

class _ServicerContext(grpc.ServicerContext, grpc.aio.ServicerContext):  # type: ignore[misc, type-arg]
    ...

class SynchronizationSessionServiceStub:
    """A set of methods for managing synchronization sessions."""

    def __init__(self, channel: typing.Union[grpc.Channel, grpc.aio.Channel]) -> None: ...
    OpenSession: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.organizationmanager.v1.idp.synchronization_session_service_pb2.OpenSessionRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Opens a new synchronization session."""

    CloseSession: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.organizationmanager.v1.idp.synchronization_session_service_pb2.CloseSessionRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Closes a synchronization session."""

    ReportSessionProgress: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.organizationmanager.v1.idp.synchronization_session_service_pb2.ReportSessionProgressRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Reports progress for a synchronization session."""

    Heartbeat: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.organizationmanager.v1.idp.synchronization_session_service_pb2.HeartbeatRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Sends a heartbeat for a synchronization session."""

    GetSession: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.organizationmanager.v1.idp.synchronization_session_service_pb2.GetSessionRequest,
        yandex.cloud.organizationmanager.v1.idp.synchronization_session_service_pb2.GetSessionResponse,
    ]
    """Returns the specified synchronization session."""

    ListSessions: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.organizationmanager.v1.idp.synchronization_session_service_pb2.ListSessionsRequest,
        yandex.cloud.organizationmanager.v1.idp.synchronization_session_service_pb2.ListSessionsResponse,
    ]
    """Lists synchronization sessions for a subject container."""

class SynchronizationSessionServiceAsyncStub:
    """A set of methods for managing synchronization sessions."""

    OpenSession: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.organizationmanager.v1.idp.synchronization_session_service_pb2.OpenSessionRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Opens a new synchronization session."""

    CloseSession: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.organizationmanager.v1.idp.synchronization_session_service_pb2.CloseSessionRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Closes a synchronization session."""

    ReportSessionProgress: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.organizationmanager.v1.idp.synchronization_session_service_pb2.ReportSessionProgressRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Reports progress for a synchronization session."""

    Heartbeat: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.organizationmanager.v1.idp.synchronization_session_service_pb2.HeartbeatRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Sends a heartbeat for a synchronization session."""

    GetSession: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.organizationmanager.v1.idp.synchronization_session_service_pb2.GetSessionRequest,
        yandex.cloud.organizationmanager.v1.idp.synchronization_session_service_pb2.GetSessionResponse,
    ]
    """Returns the specified synchronization session."""

    ListSessions: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.organizationmanager.v1.idp.synchronization_session_service_pb2.ListSessionsRequest,
        yandex.cloud.organizationmanager.v1.idp.synchronization_session_service_pb2.ListSessionsResponse,
    ]
    """Lists synchronization sessions for a subject container."""

class SynchronizationSessionServiceServicer(metaclass=abc.ABCMeta):
    """A set of methods for managing synchronization sessions."""

    @abc.abstractmethod
    def OpenSession(
        self,
        request: yandex.cloud.organizationmanager.v1.idp.synchronization_session_service_pb2.OpenSessionRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """Opens a new synchronization session."""

    @abc.abstractmethod
    def CloseSession(
        self,
        request: yandex.cloud.organizationmanager.v1.idp.synchronization_session_service_pb2.CloseSessionRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """Closes a synchronization session."""

    @abc.abstractmethod
    def ReportSessionProgress(
        self,
        request: yandex.cloud.organizationmanager.v1.idp.synchronization_session_service_pb2.ReportSessionProgressRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """Reports progress for a synchronization session."""

    @abc.abstractmethod
    def Heartbeat(
        self,
        request: yandex.cloud.organizationmanager.v1.idp.synchronization_session_service_pb2.HeartbeatRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """Sends a heartbeat for a synchronization session."""

    @abc.abstractmethod
    def GetSession(
        self,
        request: yandex.cloud.organizationmanager.v1.idp.synchronization_session_service_pb2.GetSessionRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.organizationmanager.v1.idp.synchronization_session_service_pb2.GetSessionResponse, collections.abc.Awaitable[yandex.cloud.organizationmanager.v1.idp.synchronization_session_service_pb2.GetSessionResponse]]:
        """Returns the specified synchronization session."""

    @abc.abstractmethod
    def ListSessions(
        self,
        request: yandex.cloud.organizationmanager.v1.idp.synchronization_session_service_pb2.ListSessionsRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.organizationmanager.v1.idp.synchronization_session_service_pb2.ListSessionsResponse, collections.abc.Awaitable[yandex.cloud.organizationmanager.v1.idp.synchronization_session_service_pb2.ListSessionsResponse]]:
        """Lists synchronization sessions for a subject container."""

def add_SynchronizationSessionServiceServicer_to_server(servicer: SynchronizationSessionServiceServicer, server: typing.Union[grpc.Server, grpc.aio.Server]) -> None: ...



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import google.protobuf.descriptor
import google.protobuf.message
import typing

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class RentalPeriod(google.protobuf.message.Message):
    """A period of time for which a Bare Metal Server can be rented. e.g., 1 month, 3 months, 6 months,
    a year.
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ID_FIELD_NUMBER: builtins.int
    id: builtins.str
    """Rental period identifier."""
    def __init__(
        self,
        *,
        id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["id", b"id"]) -> None: ...

global___RentalPeriod = RentalPeriod



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import abc
import collections.abc
import grpc
import grpc.aio
import typing
import yandex.cloud.billing.usage_records.v1.consumption_core_service_pb2

_T = typing.TypeVar("_T")

class _MaybeAsyncIterator(collections.abc.AsyncIterator[_T], collections.abc.Iterator[_T], metaclass=abc.ABCMeta): ...

class _ServicerContext(grpc.ServicerContext, grpc.aio.ServicerContext):  # type: ignore[misc, type-arg]
    ...

class ConsumptionCoreServiceStub:
    """Service for detailed consumption and usage reporting.

    The ConsumptionCoreService provides a comprehensive set of methods for retrieving detailed
    usage and billing information for different entities within a billing account hierarchy.
    Each method offers aggregated data for specific entity types (a billing account, clouds,
    folders, services, SKUs, resources, or labels) with support for various filtering options
    and aggregation periods. Note that each request targets a single billing account.

    All methods in this service follow the same three-level response structure:
    1. Overall totals for the entire request period (cost, credits, expense)
    2. Entity-level totals - summary data for each entity of the requested type
    3. Time series data - periodic breakdown for each entity according to the specified aggregation period
       (controlled by the aggregation_period request parameter: day/week/month/quarter/year)

    These methods help customers and internal teams analyze usage patterns, track expenses,
    monitor resource consumption, and generate detailed billing reports. The service
    supports filtering by entity IDs, date ranges, labels, and other parameters to provide
    targeted insights into cloud resource usage.

    Required permissions:
    All methods in this service require one of the following permissions on the specified billing account:
    - `billing.accounts.getReport`

    Rate limits:
    This API is limited to 1 request per minute per IP address.
    """

    def __init__(self, channel: typing.Union[grpc.Channel, grpc.aio.Channel]) -> None: ...
    GetBillingAccountUsageReport: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.billing.usage_records.v1.consumption_core_service_pb2.UsageReportRequest,
        yandex.cloud.billing.usage_records.v1.consumption_core_service_pb2.BillingAccountUsageReportResponse,
    ]
    """Returns aggregated usage report for a single specified billing account,
    optionally filtered by clouds, folders, SKUs, labels, and period granularity.

    This method provides a comprehensive view of all usage and costs for a specific
    billing account, with options to filter data by various entity types and to aggregate
    results at different time granularities (daily, monthly, etc.).

    Implementation details:
    - The report includes the total cost, applied credits (monetary grants, volume incentives, committed use discounts, and free credits), and final expense
    - Results can be filtered by cloud IDs, folder IDs, service IDs, SKU IDs, resource IDs, or labels
    - All applicable filters from the request will be applied (with AND logic between different filter types)
    - Time-based data is grouped according to the specified aggregation period

    Error handling:
    - Returns INVALID_ARGUMENT if the request parameters fail validation
    - Returns UNAUTHENTICATED if the user is not authenticated or the billing account does not exist
    - Returns PERMISSION_DENIED if the user lacks required permissions
    - Returns INTERNAL for internal server errors
    """

    GetCloudUsageReport: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.billing.usage_records.v1.consumption_core_service_pb2.UsageReportRequest,
        yandex.cloud.billing.usage_records.v1.consumption_core_service_pb2.CloudUsageReportResponse,
    ]
    """Returns aggregated usage report for the specified clouds
    under the specified billing account.

    This method provides detailed usage and cost information grouped by clouds
    within the specified billing account. The data can be filtered by various
    entity types and aggregated at different time granularities.

    Implementation details:
    - Results are organized by cloud, with each cloud's usage, costs, and credits detailed
    - If cloud_ids are specified, only data for those clouds is included (using OR logic)
    - When no cloud_ids are specified, data for all clouds under the billing account is returned
    - Other filters (folder_ids, service_ids, sku_ids, resource_ids, labels) are always applied if present
    - Hierarchical data structure allows analyzing costs across the organization's cloud resources

    Error handling:
    - Returns INVALID_ARGUMENT if the request parameters fail validation
    - Returns UNAUTHENTICATED if the user is not authenticated or the billing account does not exist
    - Returns PERMISSION_DENIED if the user lacks required permissions
    - Returns INTERNAL for internal server errors
    """

    GetFolderUsageReport: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.billing.usage_records.v1.consumption_core_service_pb2.UsageReportRequest,
        yandex.cloud.billing.usage_records.v1.consumption_core_service_pb2.FolderUsageReportResponse,
    ]
    """Returns aggregated usage report for the specified folders
    under the specified billing account.

    This method provides detailed usage and cost information grouped by folders
    within the specified billing account. The data can be filtered by various
    entity types and aggregated at different time granularities.

    Implementation details:
    - Results are organized by folder, with each folder's usage, costs, and credits detailed
    - If folder_ids are specified, only data for those folders is included (using OR logic)
    - When no folder_ids are specified, data for all folders under the billing account is returned
    - Other filters (cloud_ids, service_ids, sku_ids, resource_ids, labels) are always applied if present
    - Provides visibility into costs at the project/folder level within your organization

    Error handling:
    - Returns INVALID_ARGUMENT if the request parameters fail validation
    - Returns UNAUTHENTICATED if the user is not authenticated or the billing account does not exist
    - Returns PERMISSION_DENIED if the user lacks required permissions
    - Returns INTERNAL for internal server errors

    Required permissions:
    - `billing.accounts.getReport` on the specified billing account
    """

    GetServiceUsageReport: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.billing.usage_records.v1.consumption_core_service_pb2.UsageReportRequest,
        yandex.cloud.billing.usage_records.v1.consumption_core_service_pb2.ServiceUsageReportResponse,
    ]
    """Returns aggregated usage report for the specified services
    under the specified billing account.

    This method provides detailed usage and cost information grouped by services
    within the specified billing account. Services represent broad product categories
    (like Compute, Storage, AI, etc.) that contain multiple SKUs. The data can be
    filtered by various entity types and aggregated at different time granularities.

    Implementation details:
    - Results are organized by service, with each service's usage, costs, and credits detailed
    - If service_ids are specified, only data for those services is included (using OR logic)
    - When no service_ids are specified, data for all services under the billing account is returned
    - Other filters (cloud_ids, folder_ids, sku_ids, resource_ids, labels) are always applied if present
    - Service data includes the service name and description
    - Helps identify which cloud services are driving your overall costs

    Error handling:
    - Returns INVALID_ARGUMENT if the request parameters fail validation
    - Returns UNAUTHENTICATED if the user is not authenticated or the billing account does not exist
    - Returns PERMISSION_DENIED if the user lacks required permissions
    - Returns INTERNAL for internal server errors
    """

    GetSKUUsageReport: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.billing.usage_records.v1.consumption_core_service_pb2.UsageReportRequest,
        yandex.cloud.billing.usage_records.v1.consumption_core_service_pb2.SKUUsageReportResponse,
    ]
    """Returns aggregated usage report by SKU (Stock Keeping Unit)
    under the specified billing account.

    This method provides detailed usage and cost information grouped by SKUs
    within the specified billing account. SKUs are specific billable product offerings
    (such as specific VM types, disk types, or AI models) that belong to a parent service.
    The data can be filtered by various entity types and aggregated at different time granularities.

    Implementation details:
    - Results are organized by SKU, with each SKU's usage, costs, and credits detailed
    - If sku_ids are specified, only data for those SKUs is included (using OR logic)
    - When no sku_ids are specified, data for all SKUs under the billing account is returned
    - Other filters (cloud_ids, folder_ids, service_ids, resource_ids, labels) are always applied if present
    - SKU data includes pricing quantity, unit of measurement, and translated display names
    - Provides the most granular view of which specific product offerings are generating costs

    Error handling:
    - Returns INVALID_ARGUMENT if the request parameters fail validation
    - Returns UNAUTHENTICATED if the user is not authenticated or the billing account does not exist
    - Returns PERMISSION_DENIED if the user lacks required permissions
    - Returns INTERNAL for internal server errors
    """

    GetResourceUsageReport: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.billing.usage_records.v1.consumption_core_service_pb2.UsageReportRequest,
        yandex.cloud.billing.usage_records.v1.consumption_core_service_pb2.ResourceUsageReportResponse,
    ]
    """Returns aggregated usage report by individual resource
    under the specified billing account.

    This method provides detailed usage and cost information grouped by individual resources
    within the specified billing account. The data can be filtered by various
    entity types and aggregated at different time granularities.

    Implementation details:
    - Results are organized by resource, with each resource's usage, costs, and credits detailed
    - If resource_ids are specified, only data for those resources is included (using OR logic)
    - When no resource_ids are specified, data for all resources under the billing account is returned
    - Other filters (cloud_ids, folder_ids, service_ids, sku_ids, labels) are always applied if present
    - This provides the most granular view of costs as it breaks down to the individual resource level
    - Enables precise cost analysis at the individual resource instance level (specific VMs, disks, etc.)

    Error handling:
    - Returns INVALID_ARGUMENT if the request parameters fail validation
    - Returns UNAUTHENTICATED if the user is not authenticated or the billing account does not exist
    - Returns PERMISSION_DENIED if the user lacks required permissions
    - Returns INTERNAL for internal server errors
    """

    GetLabelKeyUsageReport: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.billing.usage_records.v1.consumption_core_service_pb2.UsageReportRequest,
        yandex.cloud.billing.usage_records.v1.consumption_core_service_pb2.LabelKeyUsageReportResponse,
    ]
    """Returns aggregated usage report by label keys and values
    under the specified billing account.

    This method provides detailed usage and cost information grouped by label key-value pairs
    within the specified billing account. Labels are user-defined metadata tags attached to resources
    (such as VMs, disks, etc.) in the form of key-value pairs (e.g., "env:prod", "region:us-west").
    The data can be filtered by various entity types and aggregated at different time granularities.

    Implementation details:
    - Results are organized by label key-value pairs, with usage, costs, and credits detailed for each
    - If labels filter is specified, only data for matching labels is included
    - Other filters (cloud_ids, folder_ids, service_ids, sku_ids, resource_ids) are always applied if present
    - Resources can have multiple labels attached (e.g., a VM might have "env:prod", "team:finance", "region:us")
    - If a resource has multiple labels at the same point in time, the usage and cost metrics are reported for each label separately.
      In other words, the same resource's cost is **duplicated** across its labels rather than split. For example,
      if a VM costs 90 units and has 3 labels, the report will show 90 units for each label, not 30 units per label.
    - This allows for custom business dimensions analysis based on resource tagging
    - Usage data is aggregated for all resources that share the same label
    - Particularly useful for cost allocation and chargeback across business units, environments, or projects

    Error handling:
    - Returns INVALID_ARGUMENT if the request parameters fail validation
    - Returns UNAUTHENTICATED if the user is not authenticated or the billing account does not exist
    - Returns PERMISSION_DENIED if the user lacks required permissions
    - Returns INTERNAL for internal server errors
    """

class ConsumptionCoreServiceAsyncStub:
    """Service for detailed consumption and usage reporting.

    The ConsumptionCoreService provides a comprehensive set of methods for retrieving detailed
    usage and billing information for different entities within a billing account hierarchy.
    Each method offers aggregated data for specific entity types (a billing account, clouds,
    folders, services, SKUs, resources, or labels) with support for various filtering options
    and aggregation periods. Note that each request targets a single billing account.

    All methods in this service follow the same three-level response structure:
    1. Overall totals for the entire request period (cost, credits, expense)
    2. Entity-level totals - summary data for each entity of the requested type
    3. Time series data - periodic breakdown for each entity according to the specified aggregation period
       (controlled by the aggregation_period request parameter: day/week/month/quarter/year)

    These methods help customers and internal teams analyze usage patterns, track expenses,
    monitor resource consumption, and generate detailed billing reports. The service
    supports filtering by entity IDs, date ranges, labels, and other parameters to provide
    targeted insights into cloud resource usage.

    Required permissions:
    All methods in this service require one of the following permissions on the specified billing account:
    - `billing.accounts.getReport`

    Rate limits:
    This API is limited to 1 request per minute per IP address.
    """

    GetBillingAccountUsageReport: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.billing.usage_records.v1.consumption_core_service_pb2.UsageReportRequest,
        yandex.cloud.billing.usage_records.v1.consumption_core_service_pb2.BillingAccountUsageReportResponse,
    ]
    """Returns aggregated usage report for a single specified billing account,
    optionally filtered by clouds, folders, SKUs, labels, and period granularity.

    This method provides a comprehensive view of all usage and costs for a specific
    billing account, with options to filter data by various entity types and to aggregate
    results at different time granularities (daily, monthly, etc.).

    Implementation details:
    - The report includes the total cost, applied credits (monetary grants, volume incentives, committed use discounts, and free credits), and final expense
    - Results can be filtered by cloud IDs, folder IDs, service IDs, SKU IDs, resource IDs, or labels
    - All applicable filters from the request will be applied (with AND logic between different filter types)
    - Time-based data is grouped according to the specified aggregation period

    Error handling:
    - Returns INVALID_ARGUMENT if the request parameters fail validation
    - Returns UNAUTHENTICATED if the user is not authenticated or the billing account does not exist
    - Returns PERMISSION_DENIED if the user lacks required permissions
    - Returns INTERNAL for internal server errors
    """

    GetCloudUsageReport: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.billing.usage_records.v1.consumption_core_service_pb2.UsageReportRequest,
        yandex.cloud.billing.usage_records.v1.consumption_core_service_pb2.CloudUsageReportResponse,
    ]
    """Returns aggregated usage report for the specified clouds
    under the specified billing account.

    This method provides detailed usage and cost information grouped by clouds
    within the specified billing account. The data can be filtered by various
    entity types and aggregated at different time granularities.

    Implementation details:
    - Results are organized by cloud, with each cloud's usage, costs, and credits detailed
    - If cloud_ids are specified, only data for those clouds is included (using OR logic)
    - When no cloud_ids are specified, data for all clouds under the billing account is returned
    - Other filters (folder_ids, service_ids, sku_ids, resource_ids, labels) are always applied if present
    - Hierarchical data structure allows analyzing costs across the organization's cloud resources

    Error handling:
    - Returns INVALID_ARGUMENT if the request parameters fail validation
    - Returns UNAUTHENTICATED if the user is not authenticated or the billing account does not exist
    - Returns PERMISSION_DENIED if the user lacks required permissions
    - Returns INTERNAL for internal server errors
    """

    GetFolderUsageReport: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.billing.usage_records.v1.consumption_core_service_pb2.UsageReportRequest,
        yandex.cloud.billing.usage_records.v1.consumption_core_service_pb2.FolderUsageReportResponse,
    ]
    """Returns aggregated usage report for the specified folders
    under the specified billing account.

    This method provides detailed usage and cost information grouped by folders
    within the specified billing account. The data can be filtered by various
    entity types and aggregated at different time granularities.

    Implementation details:
    - Results are organized by folder, with each folder's usage, costs, and credits detailed
    - If folder_ids are specified, only data for those folders is included (using OR logic)
    - When no folder_ids are specified, data for all folders under the billing account is returned
    - Other filters (cloud_ids, service_ids, sku_ids, resource_ids, labels) are always applied if present
    - Provides visibility into costs at the project/folder level within your organization

    Error handling:
    - Returns INVALID_ARGUMENT if the request parameters fail validation
    - Returns UNAUTHENTICATED if the user is not authenticated or the billing account does not exist
    - Returns PERMISSION_DENIED if the user lacks required permissions
    - Returns INTERNAL for internal server errors

    Required permissions:
    - `billing.accounts.getReport` on the specified billing account
    """

    GetServiceUsageReport: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.billing.usage_records.v1.consumption_core_service_pb2.UsageReportRequest,
        yandex.cloud.billing.usage_records.v1.consumption_core_service_pb2.ServiceUsageReportResponse,
    ]
    """Returns aggregated usage report for the specified services
    under the specified billing account.

    This method provides detailed usage and cost information grouped by services
    within the specified billing account. Services represent broad product categories
    (like Compute, Storage, AI, etc.) that contain multiple SKUs. The data can be
    filtered by various entity types and aggregated at different time granularities.

    Implementation details:
    - Results are organized by service, with each service's usage, costs, and credits detailed
    - If service_ids are specified, only data for those services is included (using OR logic)
    - When no service_ids are specified, data for all services under the billing account is returned
    - Other filters (cloud_ids, folder_ids, sku_ids, resource_ids, labels) are always applied if present
    - Service data includes the service name and description
    - Helps identify which cloud services are driving your overall costs

    Error handling:
    - Returns INVALID_ARGUMENT if the request parameters fail validation
    - Returns UNAUTHENTICATED if the user is not authenticated or the billing account does not exist
    - Returns PERMISSION_DENIED if the user lacks required permissions
    - Returns INTERNAL for internal server errors
    """

    GetSKUUsageReport: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.billing.usage_records.v1.consumption_core_service_pb2.UsageReportRequest,
        yandex.cloud.billing.usage_records.v1.consumption_core_service_pb2.SKUUsageReportResponse,
    ]
    """Returns aggregated usage report by SKU (Stock Keeping Unit)
    under the specified billing account.

    This method provides detailed usage and cost information grouped by SKUs
    within the specified billing account. SKUs are specific billable product offerings
    (such as specific VM types, disk types, or AI models) that belong to a parent service.
    The data can be filtered by various entity types and aggregated at different time granularities.

    Implementation details:
    - Results are organized by SKU, with each SKU's usage, costs, and credits detailed
    - If sku_ids are specified, only data for those SKUs is included (using OR logic)
    - When no sku_ids are specified, data for all SKUs under the billing account is returned
    - Other filters (cloud_ids, folder_ids, service_ids, resource_ids, labels) are always applied if present
    - SKU data includes pricing quantity, unit of measurement, and translated display names
    - Provides the most granular view of which specific product offerings are generating costs

    Error handling:
    - Returns INVALID_ARGUMENT if the request parameters fail validation
    - Returns UNAUTHENTICATED if the user is not authenticated or the billing account does not exist
    - Returns PERMISSION_DENIED if the user lacks required permissions
    - Returns INTERNAL for internal server errors
    """

    GetResourceUsageReport: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.billing.usage_records.v1.consumption_core_service_pb2.UsageReportRequest,
        yandex.cloud.billing.usage_records.v1.consumption_core_service_pb2.ResourceUsageReportResponse,
    ]
    """Returns aggregated usage report by individual resource
    under the specified billing account.

    This method provides detailed usage and cost information grouped by individual resources
    within the specified billing account. The data can be filtered by various
    entity types and aggregated at different time granularities.

    Implementation details:
    - Results are organized by resource, with each resource's usage, costs, and credits detailed
    - If resource_ids are specified, only data for those resources is included (using OR logic)
    - When no resource_ids are specified, data for all resources under the billing account is returned
    - Other filters (cloud_ids, folder_ids, service_ids, sku_ids, labels) are always applied if present
    - This provides the most granular view of costs as it breaks down to the individual resource level
    - Enables precise cost analysis at the individual resource instance level (specific VMs, disks, etc.)

    Error handling:
    - Returns INVALID_ARGUMENT if the request parameters fail validation
    - Returns UNAUTHENTICATED if the user is not authenticated or the billing account does not exist
    - Returns PERMISSION_DENIED if the user lacks required permissions
    - Returns INTERNAL for internal server errors
    """

    GetLabelKeyUsageReport: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.billing.usage_records.v1.consumption_core_service_pb2.UsageReportRequest,
        yandex.cloud.billing.usage_records.v1.consumption_core_service_pb2.LabelKeyUsageReportResponse,
    ]
    """Returns aggregated usage report by label keys and values
    under the specified billing account.

    This method provides detailed usage and cost information grouped by label key-value pairs
    within the specified billing account. Labels are user-defined metadata tags attached to resources
    (such as VMs, disks, etc.) in the form of key-value pairs (e.g., "env:prod", "region:us-west").
    The data can be filtered by various entity types and aggregated at different time granularities.

    Implementation details:
    - Results are organized by label key-value pairs, with usage, costs, and credits detailed for each
    - If labels filter is specified, only data for matching labels is included
    - Other filters (cloud_ids, folder_ids, service_ids, sku_ids, resource_ids) are always applied if present
    - Resources can have multiple labels attached (e.g., a VM might have "env:prod", "team:finance", "region:us")
    - If a resource has multiple labels at the same point in time, the usage and cost metrics are reported for each label separately.
      In other words, the same resource's cost is **duplicated** across its labels rather than split. For example,
      if a VM costs 90 units and has 3 labels, the report will show 90 units for each label, not 30 units per label.
    - This allows for custom business dimensions analysis based on resource tagging
    - Usage data is aggregated for all resources that share the same label
    - Particularly useful for cost allocation and chargeback across business units, environments, or projects

    Error handling:
    - Returns INVALID_ARGUMENT if the request parameters fail validation
    - Returns UNAUTHENTICATED if the user is not authenticated or the billing account does not exist
    - Returns PERMISSION_DENIED if the user lacks required permissions
    - Returns INTERNAL for internal server errors
    """

class ConsumptionCoreServiceServicer(metaclass=abc.ABCMeta):
    """Service for detailed consumption and usage reporting.

    The ConsumptionCoreService provides a comprehensive set of methods for retrieving detailed
    usage and billing information for different entities within a billing account hierarchy.
    Each method offers aggregated data for specific entity types (a billing account, clouds,
    folders, services, SKUs, resources, or labels) with support for various filtering options
    and aggregation periods. Note that each request targets a single billing account.

    All methods in this service follow the same three-level response structure:
    1. Overall totals for the entire request period (cost, credits, expense)
    2. Entity-level totals - summary data for each entity of the requested type
    3. Time series data - periodic breakdown for each entity according to the specified aggregation period
       (controlled by the aggregation_period request parameter: day/week/month/quarter/year)

    These methods help customers and internal teams analyze usage patterns, track expenses,
    monitor resource consumption, and generate detailed billing reports. The service
    supports filtering by entity IDs, date ranges, labels, and other parameters to provide
    targeted insights into cloud resource usage.

    Required permissions:
    All methods in this service require one of the following permissions on the specified billing account:
    - `billing.accounts.getReport`

    Rate limits:
    This API is limited to 1 request per minute per IP address.
    """

    @abc.abstractmethod
    def GetBillingAccountUsageReport(
        self,
        request: yandex.cloud.billing.usage_records.v1.consumption_core_service_pb2.UsageReportRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.billing.usage_records.v1.consumption_core_service_pb2.BillingAccountUsageReportResponse, collections.abc.Awaitable[yandex.cloud.billing.usage_records.v1.consumption_core_service_pb2.BillingAccountUsageReportResponse]]:
        """Returns aggregated usage report for a single specified billing account,
        optionally filtered by clouds, folders, SKUs, labels, and period granularity.

        This method provides a comprehensive view of all usage and costs for a specific
        billing account, with options to filter data by various entity types and to aggregate
        results at different time granularities (daily, monthly, etc.).

        Implementation details:
        - The report includes the total cost, applied credits (monetary grants, volume incentives, committed use discounts, and free credits), and final expense
        - Results can be filtered by cloud IDs, folder IDs, service IDs, SKU IDs, resource IDs, or labels
        - All applicable filters from the request will be applied (with AND logic between different filter types)
        - Time-based data is grouped according to the specified aggregation period

        Error handling:
        - Returns INVALID_ARGUMENT if the request parameters fail validation
        - Returns UNAUTHENTICATED if the user is not authenticated or the billing account does not exist
        - Returns PERMISSION_DENIED if the user lacks required permissions
        - Returns INTERNAL for internal server errors
        """

    @abc.abstractmethod
    def GetCloudUsageReport(
        self,
        request: yandex.cloud.billing.usage_records.v1.consumption_core_service_pb2.UsageReportRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.billing.usage_records.v1.consumption_core_service_pb2.CloudUsageReportResponse, collections.abc.Awaitable[yandex.cloud.billing.usage_records.v1.consumption_core_service_pb2.CloudUsageReportResponse]]:
        """Returns aggregated usage report for the specified clouds
        under the specified billing account.

        This method provides detailed usage and cost information grouped by clouds
        within the specified billing account. The data can be filtered by various
        entity types and aggregated at different time granularities.

        Implementation details:
        - Results are organized by cloud, with each cloud's usage, costs, and credits detailed
        - If cloud_ids are specified, only data for those clouds is included (using OR logic)
        - When no cloud_ids are specified, data for all clouds under the billing account is returned
        - Other filters (folder_ids, service_ids, sku_ids, resource_ids, labels) are always applied if present
        - Hierarchical data structure allows analyzing costs across the organization's cloud resources

        Error handling:
        - Returns INVALID_ARGUMENT if the request parameters fail validation
        - Returns UNAUTHENTICATED if the user is not authenticated or the billing account does not exist
        - Returns PERMISSION_DENIED if the user lacks required permissions
        - Returns INTERNAL for internal server errors
        """

    @abc.abstractmethod
    def GetFolderUsageReport(
        self,
        request: yandex.cloud.billing.usage_records.v1.consumption_core_service_pb2.UsageReportRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.billing.usage_records.v1.consumption_core_service_pb2.FolderUsageReportResponse, collections.abc.Awaitable[yandex.cloud.billing.usage_records.v1.consumption_core_service_pb2.FolderUsageReportResponse]]:
        """Returns aggregated usage report for the specified folders
        under the specified billing account.

        This method provides detailed usage and cost information grouped by folders
        within the specified billing account. The data can be filtered by various
        entity types and aggregated at different time granularities.

        Implementation details:
        - Results are organized by folder, with each folder's usage, costs, and credits detailed
        - If folder_ids are specified, only data for those folders is included (using OR logic)
        - When no folder_ids are specified, data for all folders under the billing account is returned
        - Other filters (cloud_ids, service_ids, sku_ids, resource_ids, labels) are always applied if present
        - Provides visibility into costs at the project/folder level within your organization

        Error handling:
        - Returns INVALID_ARGUMENT if the request parameters fail validation
        - Returns UNAUTHENTICATED if the user is not authenticated or the billing account does not exist
        - Returns PERMISSION_DENIED if the user lacks required permissions
        - Returns INTERNAL for internal server errors

        Required permissions:
        - `billing.accounts.getReport` on the specified billing account
        """

    @abc.abstractmethod
    def GetServiceUsageReport(
        self,
        request: yandex.cloud.billing.usage_records.v1.consumption_core_service_pb2.UsageReportRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.billing.usage_records.v1.consumption_core_service_pb2.ServiceUsageReportResponse, collections.abc.Awaitable[yandex.cloud.billing.usage_records.v1.consumption_core_service_pb2.ServiceUsageReportResponse]]:
        """Returns aggregated usage report for the specified services
        under the specified billing account.

        This method provides detailed usage and cost information grouped by services
        within the specified billing account. Services represent broad product categories
        (like Compute, Storage, AI, etc.) that contain multiple SKUs. The data can be
        filtered by various entity types and aggregated at different time granularities.

        Implementation details:
        - Results are organized by service, with each service's usage, costs, and credits detailed
        - If service_ids are specified, only data for those services is included (using OR logic)
        - When no service_ids are specified, data for all services under the billing account is returned
        - Other filters (cloud_ids, folder_ids, sku_ids, resource_ids, labels) are always applied if present
        - Service data includes the service name and description
        - Helps identify which cloud services are driving your overall costs

        Error handling:
        - Returns INVALID_ARGUMENT if the request parameters fail validation
        - Returns UNAUTHENTICATED if the user is not authenticated or the billing account does not exist
        - Returns PERMISSION_DENIED if the user lacks required permissions
        - Returns INTERNAL for internal server errors
        """

    @abc.abstractmethod
    def GetSKUUsageReport(
        self,
        request: yandex.cloud.billing.usage_records.v1.consumption_core_service_pb2.UsageReportRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.billing.usage_records.v1.consumption_core_service_pb2.SKUUsageReportResponse, collections.abc.Awaitable[yandex.cloud.billing.usage_records.v1.consumption_core_service_pb2.SKUUsageReportResponse]]:
        """Returns aggregated usage report by SKU (Stock Keeping Unit)
        under the specified billing account.

        This method provides detailed usage and cost information grouped by SKUs
        within the specified billing account. SKUs are specific billable product offerings
        (such as specific VM types, disk types, or AI models) that belong to a parent service.
        The data can be filtered by various entity types and aggregated at different time granularities.

        Implementation details:
        - Results are organized by SKU, with each SKU's usage, costs, and credits detailed
        - If sku_ids are specified, only data for those SKUs is included (using OR logic)
        - When no sku_ids are specified, data for all SKUs under the billing account is returned
        - Other filters (cloud_ids, folder_ids, service_ids, resource_ids, labels) are always applied if present
        - SKU data includes pricing quantity, unit of measurement, and translated display names
        - Provides the most granular view of which specific product offerings are generating costs

        Error handling:
        - Returns INVALID_ARGUMENT if the request parameters fail validation
        - Returns UNAUTHENTICATED if the user is not authenticated or the billing account does not exist
        - Returns PERMISSION_DENIED if the user lacks required permissions
        - Returns INTERNAL for internal server errors
        """

    @abc.abstractmethod
    def GetResourceUsageReport(
        self,
        request: yandex.cloud.billing.usage_records.v1.consumption_core_service_pb2.UsageReportRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.billing.usage_records.v1.consumption_core_service_pb2.ResourceUsageReportResponse, collections.abc.Awaitable[yandex.cloud.billing.usage_records.v1.consumption_core_service_pb2.ResourceUsageReportResponse]]:
        """Returns aggregated usage report by individual resource
        under the specified billing account.

        This method provides detailed usage and cost information grouped by individual resources
        within the specified billing account. The data can be filtered by various
        entity types and aggregated at different time granularities.

        Implementation details:
        - Results are organized by resource, with each resource's usage, costs, and credits detailed
        - If resource_ids are specified, only data for those resources is included (using OR logic)
        - When no resource_ids are specified, data for all resources under the billing account is returned
        - Other filters (cloud_ids, folder_ids, service_ids, sku_ids, labels) are always applied if present
        - This provides the most granular view of costs as it breaks down to the individual resource level
        - Enables precise cost analysis at the individual resource instance level (specific VMs, disks, etc.)

        Error handling:
        - Returns INVALID_ARGUMENT if the request parameters fail validation
        - Returns UNAUTHENTICATED if the user is not authenticated or the billing account does not exist
        - Returns PERMISSION_DENIED if the user lacks required permissions
        - Returns INTERNAL for internal server errors
        """

    @abc.abstractmethod
    def GetLabelKeyUsageReport(
        self,
        request: yandex.cloud.billing.usage_records.v1.consumption_core_service_pb2.UsageReportRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.billing.usage_records.v1.consumption_core_service_pb2.LabelKeyUsageReportResponse, collections.abc.Awaitable[yandex.cloud.billing.usage_records.v1.consumption_core_service_pb2.LabelKeyUsageReportResponse]]:
        """Returns aggregated usage report by label keys and values
        under the specified billing account.

        This method provides detailed usage and cost information grouped by label key-value pairs
        within the specified billing account. Labels are user-defined metadata tags attached to resources
        (such as VMs, disks, etc.) in the form of key-value pairs (e.g., "env:prod", "region:us-west").
        The data can be filtered by various entity types and aggregated at different time granularities.

        Implementation details:
        - Results are organized by label key-value pairs, with usage, costs, and credits detailed for each
        - If labels filter is specified, only data for matching labels is included
        - Other filters (cloud_ids, folder_ids, service_ids, sku_ids, resource_ids) are always applied if present
        - Resources can have multiple labels attached (e.g., a VM might have "env:prod", "team:finance", "region:us")
        - If a resource has multiple labels at the same point in time, the usage and cost metrics are reported for each label separately.
          In other words, the same resource's cost is **duplicated** across its labels rather than split. For example,
          if a VM costs 90 units and has 3 labels, the report will show 90 units for each label, not 30 units per label.
        - This allows for custom business dimensions analysis based on resource tagging
        - Usage data is aggregated for all resources that share the same label
        - Particularly useful for cost allocation and chargeback across business units, environments, or projects

        Error handling:
        - Returns INVALID_ARGUMENT if the request parameters fail validation
        - Returns UNAUTHENTICATED if the user is not authenticated or the billing account does not exist
        - Returns PERMISSION_DENIED if the user lacks required permissions
        - Returns INTERNAL for internal server errors
        """

def add_ConsumptionCoreServiceServicer_to_server(servicer: ConsumptionCoreServiceServicer, server: typing.Union[grpc.Server, grpc.aio.Server]) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: yandex/cloud/organizationmanager/v1/idp/application/saml/signature_certificate_service.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'yandex/cloud/organizationmanager/v1/idp/application/saml/signature_certificate_service.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.protobuf import field_mask_pb2 as google_dot_protobuf_dot_field__mask__pb2
from yandex.cloud.api import operation_pb2 as yandex_dot_cloud_dot_api_dot_operation__pb2
from yandex.cloud.organizationmanager.v1.idp.application.saml import signature_certificate_pb2 as yandex_dot_cloud_dot_organizationmanager_dot_v1_dot_idp_dot_application_dot_saml_dot_signature__certificate__pb2
from yandex.cloud.operation import operation_pb2 as yandex_dot_cloud_dot_operation_dot_operation__pb2
from yandex.cloud import validation_pb2 as yandex_dot_cloud_dot_validation__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\\yandex/cloud/organizationmanager/v1/idp/application/saml/signature_certificate_service.proto\x12\x38yandex.cloud.organizationmanager.v1.idp.application.saml\x1a\x1cgoogle/api/annotations.proto\x1a google/protobuf/field_mask.proto\x1a yandex/cloud/api/operation.proto\x1aTyandex/cloud/organizationmanager/v1/idp/application/saml/signature_certificate.proto\x1a&yandex/cloud/operation/operation.proto\x1a\x1dyandex/cloud/validation.proto\"P\n\x1eGetSignatureCertificateRequest\x12.\n\x18signature_certificate_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\"\xa3\x01\n ListSignatureCertificatesRequest\x12$\n\x0e\x61pplication_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x1d\n\tpage_size\x18\x02 \x01(\x03\x42\n\xfa\xc7\x31\x06\x30-1000\x12\x1e\n\npage_token\x18\x03 \x01(\tB\n\x8a\xc8\x31\x06<=2000\x12\x1a\n\x06\x66ilter\x18\x04 \x01(\tB\n\x8a\xc8\x31\x06<=1000\"\xac\x01\n!ListSignatureCertificatesResponse\x12n\n\x16signature_certificates\x18\x01 \x03(\x0b\x32N.yandex.cloud.organizationmanager.v1.idp.application.saml.SignatureCertificate\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"\x9f\x01\n!CreateSignatureCertificateRequest\x12$\n\x0e\x61pplication_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x34\n\x04name\x18\x02 \x01(\tB&\xf2\xc7\x31\"([a-z]([-a-z0-9]{0,61}[a-z0-9])?)?\x12\x1e\n\x0b\x64\x65scription\x18\x03 \x01(\tB\t\x8a\xc8\x31\x05<=256\"F\n\"CreateSignatureCertificateMetadata\x12 \n\x18signature_certificate_id\x18\x01 \x01(\t\"\xd8\x01\n!UpdateSignatureCertificateRequest\x12.\n\x18signature_certificate_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12/\n\x0bupdate_mask\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.FieldMask\x12\x32\n\x04name\x18\x03 \x01(\tB$\xf2\xc7\x31 |[a-z]([-a-z0-9]{0,61}[a-z0-9])?\x12\x1e\n\x0b\x64\x65scription\x18\x04 \x01(\tB\t\x8a\xc8\x31\x05<=256\"F\n\"UpdateSignatureCertificateMetadata\x12 \n\x18signature_certificate_id\x18\x01 \x01(\t\"O\n!DeleteSignatureCertificateRequest\x12*\n\x18signature_certificate_id\x18\x01 \x01(\tB\x08\x8a\xc8\x31\x04<=50\"F\n\"DeleteSignatureCertificateMetadata\x12 \n\x18signature_certificate_id\x18\x01 \x01(\t2\xcd\x0b\n\x1bSignatureCertificateService\x12\x98\x02\n\x03Get\x12X.yandex.cloud.organizationmanager.v1.idp.application.saml.GetSignatureCertificateRequest\x1aN.yandex.cloud.organizationmanager.v1.idp.application.saml.SignatureCertificate\"g\x82\xd3\xe4\x93\x02\x61\x12_/organization-manager/v1/idp/application/saml/signature-certificates/{signature_certificate_id}\x12\x8d\x02\n\x04List\x12Z.yandex.cloud.organizationmanager.v1.idp.application.saml.ListSignatureCertificatesRequest\x1a[.yandex.cloud.organizationmanager.v1.idp.application.saml.ListSignatureCertificatesResponse\"L\x82\xd3\xe4\x93\x02\x46\x12\x44/organization-manager/v1/idp/application/saml/signature-certificates\x12\x98\x02\n\x06\x43reate\x12[.yandex.cloud.organizationmanager.v1.idp.application.saml.CreateSignatureCertificateRequest\x1a!.yandex.cloud.operation.Operation\"\x8d\x01\xb2\xd2*:\n\"CreateSignatureCertificateMetadata\x12\x14SignatureCertificate\x82\xd3\xe4\x93\x02I\"D/organization-manager/v1/idp/application/saml/signature-certificates:\x01*\x12\xb3\x02\n\x06Update\x12[.yandex.cloud.organizationmanager.v1.idp.application.saml.UpdateSignatureCertificateRequest\x1a!.yandex.cloud.operation.Operation\"\xa8\x01\xb2\xd2*:\n\"UpdateSignatureCertificateMetadata\x12\x14SignatureCertificate\x82\xd3\xe4\x93\x02\x64\x32_/organization-manager/v1/idp/application/saml/signature-certificates/{signature_certificate_id}:\x01*\x12\xb1\x02\n\x06\x44\x65lete\x12[.yandex.cloud.organizationmanager.v1.idp.application.saml.DeleteSignatureCertificateRequest\x1a!.yandex.cloud.operation.Operation\"\xa6\x01\xb2\xd2*;\n\"DeleteSignatureCertificateMetadata\x12\x15google.protobuf.Empty\x82\xd3\xe4\x93\x02\x61*_/organization-manager/v1/idp/application/saml/signature-certificates/{signature_certificate_id}B\xa1\x01\n<yandex.cloud.api.organizationmanager.v1.idp.application.samlZagithub.com/yandex-cloud/go-genproto/yandex/cloud/organizationmanager/v1/idp/application/saml;samlb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.organizationmanager.v1.idp.application.saml.signature_certificate_service_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n<yandex.cloud.api.organizationmanager.v1.idp.application.samlZagithub.com/yandex-cloud/go-genproto/yandex/cloud/organizationmanager/v1/idp/application/saml;saml'
  _globals['_GETSIGNATURECERTIFICATEREQUEST'].fields_by_name['signature_certificate_id']._loaded_options = None
  _globals['_GETSIGNATURECERTIFICATEREQUEST'].fields_by_name['signature_certificate_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_LISTSIGNATURECERTIFICATESREQUEST'].fields_by_name['application_id']._loaded_options = None
  _globals['_LISTSIGNATURECERTIFICATESREQUEST'].fields_by_name['application_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_LISTSIGNATURECERTIFICATESREQUEST'].fields_by_name['page_size']._loaded_options = None
  _globals['_LISTSIGNATURECERTIFICATESREQUEST'].fields_by_name['page_size']._serialized_options = b'\372\3071\0060-1000'
  _globals['_LISTSIGNATURECERTIFICATESREQUEST'].fields_by_name['page_token']._loaded_options = None
  _globals['_LISTSIGNATURECERTIFICATESREQUEST'].fields_by_name['page_token']._serialized_options = b'\212\3101\006<=2000'
  _globals['_LISTSIGNATURECERTIFICATESREQUEST'].fields_by_name['filter']._loaded_options = None
  _globals['_LISTSIGNATURECERTIFICATESREQUEST'].fields_by_name['filter']._serialized_options = b'\212\3101\006<=1000'
  _globals['_CREATESIGNATURECERTIFICATEREQUEST'].fields_by_name['application_id']._loaded_options = None
  _globals['_CREATESIGNATURECERTIFICATEREQUEST'].fields_by_name['application_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_CREATESIGNATURECERTIFICATEREQUEST'].fields_by_name['name']._loaded_options = None
  _globals['_CREATESIGNATURECERTIFICATEREQUEST'].fields_by_name['name']._serialized_options = b'\362\3071\"([a-z]([-a-z0-9]{0,61}[a-z0-9])?)?'
  _globals['_CREATESIGNATURECERTIFICATEREQUEST'].fields_by_name['description']._loaded_options = None
  _globals['_CREATESIGNATURECERTIFICATEREQUEST'].fields_by_name['description']._serialized_options = b'\212\3101\005<=256'
  _globals['_UPDATESIGNATURECERTIFICATEREQUEST'].fields_by_name['signature_certificate_id']._loaded_options = None
  _globals['_UPDATESIGNATURECERTIFICATEREQUEST'].fields_by_name['signature_certificate_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_UPDATESIGNATURECERTIFICATEREQUEST'].fields_by_name['name']._loaded_options = None
  _globals['_UPDATESIGNATURECERTIFICATEREQUEST'].fields_by_name['name']._serialized_options = b'\362\3071 |[a-z]([-a-z0-9]{0,61}[a-z0-9])?'
  _globals['_UPDATESIGNATURECERTIFICATEREQUEST'].fields_by_name['description']._loaded_options = None
  _globals['_UPDATESIGNATURECERTIFICATEREQUEST'].fields_by_name['description']._serialized_options = b'\212\3101\005<=256'
  _globals['_DELETESIGNATURECERTIFICATEREQUEST'].fields_by_name['signature_certificate_id']._loaded_options = None
  _globals['_DELETESIGNATURECERTIFICATEREQUEST'].fields_by_name['signature_certificate_id']._serialized_options = b'\212\3101\004<=50'
  _globals['_SIGNATURECERTIFICATESERVICE'].methods_by_name['Get']._loaded_options = None
  _globals['_SIGNATURECERTIFICATESERVICE'].methods_by_name['Get']._serialized_options = b'\202\323\344\223\002a\022_/organization-manager/v1/idp/application/saml/signature-certificates/{signature_certificate_id}'
  _globals['_SIGNATURECERTIFICATESERVICE'].methods_by_name['List']._loaded_options = None
  _globals['_SIGNATURECERTIFICATESERVICE'].methods_by_name['List']._serialized_options = b'\202\323\344\223\002F\022D/organization-manager/v1/idp/application/saml/signature-certificates'
  _globals['_SIGNATURECERTIFICATESERVICE'].methods_by_name['Create']._loaded_options = None
  _globals['_SIGNATURECERTIFICATESERVICE'].methods_by_name['Create']._serialized_options = b'\262\322*:\n\"CreateSignatureCertificateMetadata\022\024SignatureCertificate\202\323\344\223\002I\"D/organization-manager/v1/idp/application/saml/signature-certificates:\001*'
  _globals['_SIGNATURECERTIFICATESERVICE'].methods_by_name['Update']._loaded_options = None
  _globals['_SIGNATURECERTIFICATESERVICE'].methods_by_name['Update']._serialized_options = b'\262\322*:\n\"UpdateSignatureCertificateMetadata\022\024SignatureCertificate\202\323\344\223\002d2_/organization-manager/v1/idp/application/saml/signature-certificates/{signature_certificate_id}:\001*'
  _globals['_SIGNATURECERTIFICATESERVICE'].methods_by_name['Delete']._loaded_options = None
  _globals['_SIGNATURECERTIFICATESERVICE'].methods_by_name['Delete']._serialized_options = b'\262\322*;\n\"DeleteSignatureCertificateMetadata\022\025google.protobuf.Empty\202\323\344\223\002a*_/organization-manager/v1/idp/application/saml/signature-certificates/{signature_certificate_id}'
  _globals['_GETSIGNATURECERTIFICATEREQUEST']._serialized_start=409
  _globals['_GETSIGNATURECERTIFICATEREQUEST']._serialized_end=489
  _globals['_LISTSIGNATURECERTIFICATESREQUEST']._serialized_start=492
  _globals['_LISTSIGNATURECERTIFICATESREQUEST']._serialized_end=655
  _globals['_LISTSIGNATURECERTIFICATESRESPONSE']._serialized_start=658
  _globals['_LISTSIGNATURECERTIFICATESRESPONSE']._serialized_end=830
  _globals['_CREATESIGNATURECERTIFICATEREQUEST']._serialized_start=833
  _globals['_CREATESIGNATURECERTIFICATEREQUEST']._serialized_end=992
  _globals['_CREATESIGNATURECERTIFICATEMETADATA']._serialized_start=994
  _globals['_CREATESIGNATURECERTIFICATEMETADATA']._serialized_end=1064
  _globals['_UPDATESIGNATURECERTIFICATEREQUEST']._serialized_start=1067
  _globals['_UPDATESIGNATURECERTIFICATEREQUEST']._serialized_end=1283
  _globals['_UPDATESIGNATURECERTIFICATEMETADATA']._serialized_start=1285
  _globals['_UPDATESIGNATURECERTIFICATEMETADATA']._serialized_end=1355
  _globals['_DELETESIGNATURECERTIFICATEREQUEST']._serialized_start=1357
  _globals['_DELETESIGNATURECERTIFICATEREQUEST']._serialized_end=1436
  _globals['_DELETESIGNATURECERTIFICATEMETADATA']._serialized_start=1438
  _globals['_DELETESIGNATURECERTIFICATEMETADATA']._serialized_end=1508
  _globals['_SIGNATURECERTIFICATESERVICE']._serialized_start=1511
  _globals['_SIGNATURECERTIFICATESERVICE']._serialized_end=2996
# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.duration_pb2
import google.protobuf.internal.containers
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import google.protobuf.timestamp_pb2
import sys
import typing

if sys.version_info >= (3, 10):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class Cluster(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    class _Status:
        ValueType = typing.NewType("ValueType", builtins.int)
        V: typing_extensions.TypeAlias = ValueType

    class _StatusEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[Cluster._Status.ValueType], builtins.type):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
        STATUS_UNKNOWN: Cluster._Status.ValueType  # 0
        """Unknown status."""
        CREATING: Cluster._Status.ValueType  # 1
        """Cluster is being created."""
        RUNNING: Cluster._Status.ValueType  # 2
        """Cluster is running."""
        ERROR: Cluster._Status.ValueType  # 3
        """Cluster encountered a problem and cannot operate."""
        STOPPING: Cluster._Status.ValueType  # 4
        """Cluster is being stopped."""
        STOPPED: Cluster._Status.ValueType  # 5
        """Cluster stopped."""
        STARTING: Cluster._Status.ValueType  # 6
        """Cluster is being started."""
        UPDATING: Cluster._Status.ValueType  # 7
        """Cluster is being updated."""
        DELETING: Cluster._Status.ValueType  # 8
        """Cluster is being deleted."""

    class Status(_Status, metaclass=_StatusEnumTypeWrapper): ...
    STATUS_UNKNOWN: Cluster.Status.ValueType  # 0
    """Unknown status."""
    CREATING: Cluster.Status.ValueType  # 1
    """Cluster is being created."""
    RUNNING: Cluster.Status.ValueType  # 2
    """Cluster is running."""
    ERROR: Cluster.Status.ValueType  # 3
    """Cluster encountered a problem and cannot operate."""
    STOPPING: Cluster.Status.ValueType  # 4
    """Cluster is being stopped."""
    STOPPED: Cluster.Status.ValueType  # 5
    """Cluster stopped."""
    STARTING: Cluster.Status.ValueType  # 6
    """Cluster is being started."""
    UPDATING: Cluster.Status.ValueType  # 7
    """Cluster is being updated."""
    DELETING: Cluster.Status.ValueType  # 8
    """Cluster is being deleted."""

    class _Health:
        ValueType = typing.NewType("ValueType", builtins.int)
        V: typing_extensions.TypeAlias = ValueType

    class _HealthEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[Cluster._Health.ValueType], builtins.type):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
        HEALTH_UNKNOWN: Cluster._Health.ValueType  # 0
        """Unknown health."""
        ALIVE: Cluster._Health.ValueType  # 1
        """Cluster is alive."""
        DEAD: Cluster._Health.ValueType  # 2
        """Cluster is dead."""
        DEGRADED: Cluster._Health.ValueType  # 3
        """Cluster is degraded."""

    class Health(_Health, metaclass=_HealthEnumTypeWrapper): ...
    HEALTH_UNKNOWN: Cluster.Health.ValueType  # 0
    """Unknown health."""
    ALIVE: Cluster.Health.ValueType  # 1
    """Cluster is alive."""
    DEAD: Cluster.Health.ValueType  # 2
    """Cluster is dead."""
    DEGRADED: Cluster.Health.ValueType  # 3
    """Cluster is degraded."""

    @typing.final
    class LabelsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing.Literal["key", b"key", "value", b"value"]) -> None: ...

    @typing.final
    class Endpoints(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        UI_FIELD_NUMBER: builtins.int
        EXTERNAL_HTTP_PROXY_BALANCER_FIELD_NUMBER: builtins.int
        INTERNAL_HTTP_PROXY_ALIAS_FIELD_NUMBER: builtins.int
        INTERNAL_RPC_PROXY_ALIAS_FIELD_NUMBER: builtins.int
        ui: builtins.str
        """https://CID.ytsaurus.yandexcloud.net"""
        external_http_proxy_balancer: builtins.str
        """https://proxy.CID.ytsaurus.yandexcloud.net"""
        internal_http_proxy_alias: builtins.str
        """https://hp.CID.ytsaurus.mdb.yandexcloud.net:PORT"""
        internal_rpc_proxy_alias: builtins.str
        """rp.CID.ytsaurus.mdb.yandexcloud.net:PORT"""
        def __init__(
            self,
            *,
            ui: builtins.str = ...,
            external_http_proxy_balancer: builtins.str = ...,
            internal_http_proxy_alias: builtins.str = ...,
            internal_rpc_proxy_alias: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing.Literal["external_http_proxy_balancer", b"external_http_proxy_balancer", "internal_http_proxy_alias", b"internal_http_proxy_alias", "internal_rpc_proxy_alias", b"internal_rpc_proxy_alias", "ui", b"ui"]) -> None: ...

    ID_FIELD_NUMBER: builtins.int
    FOLDER_ID_FIELD_NUMBER: builtins.int
    ZONE_ID_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    LABELS_FIELD_NUMBER: builtins.int
    SUBNET_ID_FIELD_NUMBER: builtins.int
    SECURITY_GROUP_IDS_FIELD_NUMBER: builtins.int
    SPEC_FIELD_NUMBER: builtins.int
    CREATED_AT_FIELD_NUMBER: builtins.int
    CREATED_BY_FIELD_NUMBER: builtins.int
    UPDATED_AT_FIELD_NUMBER: builtins.int
    UPDATED_BY_FIELD_NUMBER: builtins.int
    STATUS_FIELD_NUMBER: builtins.int
    HEALTH_FIELD_NUMBER: builtins.int
    ENDPOINTS_FIELD_NUMBER: builtins.int
    CIDR_BLOCKS_WHITELIST_FIELD_NUMBER: builtins.int
    id: builtins.str
    """ID of the cluster. Generated at creation time."""
    folder_id: builtins.str
    """ID of the folder that the cluster belongs to."""
    zone_id: builtins.str
    """ID of the availability zone where the cluster resides."""
    name: builtins.str
    """Name of the cluster.
    The name is unique within the folder.
    """
    description: builtins.str
    """Description of the cluster."""
    subnet_id: builtins.str
    """ID of the subnet where the cluster resides."""
    created_by: builtins.str
    """User who created the cluster."""
    updated_by: builtins.str
    """User who last updated the cluster."""
    status: global___Cluster.Status.ValueType
    """Status of the cluster."""
    health: global___Cluster.Health.ValueType
    """Health of the cluster."""
    @property
    def labels(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]:
        """Cluster labels as `key:value` pairs."""

    @property
    def security_group_ids(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
        """Network interfaces security groups."""

    @property
    def spec(self) -> global___ClusterSpec:
        """Cluster specification."""

    @property
    def created_at(self) -> google.protobuf.timestamp_pb2.Timestamp:
        """Time when the cluster was created."""

    @property
    def updated_at(self) -> google.protobuf.timestamp_pb2.Timestamp:
        """Time when the cluster was last updated."""

    @property
    def endpoints(self) -> global___Cluster.Endpoints:
        """Endpoints of the cluster."""

    @property
    def cidr_blocks_whitelist(self) -> global___CidrBlocks:
        """CIDRs whitelist."""

    def __init__(
        self,
        *,
        id: builtins.str = ...,
        folder_id: builtins.str = ...,
        zone_id: builtins.str = ...,
        name: builtins.str = ...,
        description: builtins.str = ...,
        labels: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        subnet_id: builtins.str = ...,
        security_group_ids: collections.abc.Iterable[builtins.str] | None = ...,
        spec: global___ClusterSpec | None = ...,
        created_at: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        created_by: builtins.str = ...,
        updated_at: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        updated_by: builtins.str = ...,
        status: global___Cluster.Status.ValueType = ...,
        health: global___Cluster.Health.ValueType = ...,
        endpoints: global___Cluster.Endpoints | None = ...,
        cidr_blocks_whitelist: global___CidrBlocks | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["cidr_blocks_whitelist", b"cidr_blocks_whitelist", "created_at", b"created_at", "endpoints", b"endpoints", "spec", b"spec", "updated_at", b"updated_at"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["cidr_blocks_whitelist", b"cidr_blocks_whitelist", "created_at", b"created_at", "created_by", b"created_by", "description", b"description", "endpoints", b"endpoints", "folder_id", b"folder_id", "health", b"health", "id", b"id", "labels", b"labels", "name", b"name", "security_group_ids", b"security_group_ids", "spec", b"spec", "status", b"status", "subnet_id", b"subnet_id", "updated_at", b"updated_at", "updated_by", b"updated_by", "zone_id", b"zone_id"]) -> None: ...

global___Cluster = Cluster

@typing.final
class CidrBlocks(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    V4_CIDR_BLOCKS_FIELD_NUMBER: builtins.int
    @property
    def v4_cidr_blocks(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
        """IPv4 CIDR blocks."""

    def __init__(
        self,
        *,
        v4_cidr_blocks: collections.abc.Iterable[builtins.str] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["v4_cidr_blocks", b"v4_cidr_blocks"]) -> None: ...

global___CidrBlocks = CidrBlocks

@typing.final
class StorageSpec(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing.final
    class HddSpec(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        SIZE_GB_FIELD_NUMBER: builtins.int
        COUNT_FIELD_NUMBER: builtins.int
        size_gb: builtins.int
        """Size of a single HDD disk in GB."""
        count: builtins.int
        """Total amount of HDD disks."""
        def __init__(
            self,
            *,
            size_gb: builtins.int = ...,
            count: builtins.int = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing.Literal["count", b"count", "size_gb", b"size_gb"]) -> None: ...

    @typing.final
    class SsdSpec(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        @typing.final
        class Changelogs(google.protobuf.message.Message):
            DESCRIPTOR: google.protobuf.descriptor.Descriptor

            SIZE_GB_FIELD_NUMBER: builtins.int
            size_gb: builtins.int
            """Size of changelogs disk in GB."""
            def __init__(
                self,
                *,
                size_gb: builtins.int = ...,
            ) -> None: ...
            def ClearField(self, field_name: typing.Literal["size_gb", b"size_gb"]) -> None: ...

        SIZE_GB_FIELD_NUMBER: builtins.int
        TYPE_FIELD_NUMBER: builtins.int
        COUNT_FIELD_NUMBER: builtins.int
        CHANGELOGS_FIELD_NUMBER: builtins.int
        size_gb: builtins.int
        """Size of a single SSD disk in GB."""
        type: builtins.str
        """Type of a SSD disk."""
        count: builtins.int
        """Total amount of SSD disks."""
        @property
        def changelogs(self) -> global___StorageSpec.SsdSpec.Changelogs:
            """Configuration of dynamic table changelogs."""

        def __init__(
            self,
            *,
            size_gb: builtins.int = ...,
            type: builtins.str = ...,
            count: builtins.int = ...,
            changelogs: global___StorageSpec.SsdSpec.Changelogs | None = ...,
        ) -> None: ...
        def HasField(self, field_name: typing.Literal["changelogs", b"changelogs"]) -> builtins.bool: ...
        def ClearField(self, field_name: typing.Literal["changelogs", b"changelogs", "count", b"count", "size_gb", b"size_gb", "type", b"type"]) -> None: ...

    HDD_FIELD_NUMBER: builtins.int
    SSD_FIELD_NUMBER: builtins.int
    @property
    def hdd(self) -> global___StorageSpec.HddSpec:
        """Configuration of cluster HDD strorage."""

    @property
    def ssd(self) -> global___StorageSpec.SsdSpec:
        """Configuration of cluster SSD strorage"""

    def __init__(
        self,
        *,
        hdd: global___StorageSpec.HddSpec | None = ...,
        ssd: global___StorageSpec.SsdSpec | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["hdd", b"hdd", "ssd", b"ssd"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["hdd", b"hdd", "ssd", b"ssd"]) -> None: ...

global___StorageSpec = StorageSpec

@typing.final
class ComputeSpec(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing.final
    class DiskSpec(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        TYPE_FIELD_NUMBER: builtins.int
        SIZE_GB_FIELD_NUMBER: builtins.int
        LOCATIONS_FIELD_NUMBER: builtins.int
        type: builtins.str
        """Type of a disk."""
        size_gb: builtins.int
        """Size of a single disk in GB."""
        @property
        def locations(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
            """Locations on a disk."""

        def __init__(
            self,
            *,
            type: builtins.str = ...,
            size_gb: builtins.int = ...,
            locations: collections.abc.Iterable[builtins.str] | None = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing.Literal["locations", b"locations", "size_gb", b"size_gb", "type", b"type"]) -> None: ...

    @typing.final
    class ScalePolicy(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        @typing.final
        class FixedScale(google.protobuf.message.Message):
            DESCRIPTOR: google.protobuf.descriptor.Descriptor

            SIZE_FIELD_NUMBER: builtins.int
            size: builtins.int
            """Amount of exec nodes."""
            def __init__(
                self,
                *,
                size: builtins.int = ...,
            ) -> None: ...
            def ClearField(self, field_name: typing.Literal["size", b"size"]) -> None: ...

        @typing.final
        class AutoScale(google.protobuf.message.Message):
            DESCRIPTOR: google.protobuf.descriptor.Descriptor

            MIN_SIZE_FIELD_NUMBER: builtins.int
            MAX_SIZE_FIELD_NUMBER: builtins.int
            min_size: builtins.int
            """Minimal amount of exec nodes."""
            max_size: builtins.int
            """Maximum amount of exec nodes."""
            def __init__(
                self,
                *,
                min_size: builtins.int = ...,
                max_size: builtins.int = ...,
            ) -> None: ...
            def ClearField(self, field_name: typing.Literal["max_size", b"max_size", "min_size", b"min_size"]) -> None: ...

        FIXED_FIELD_NUMBER: builtins.int
        AUTO_FIELD_NUMBER: builtins.int
        @property
        def fixed(self) -> global___ComputeSpec.ScalePolicy.FixedScale:
            """Scale policy that doesn't change number of running exec nodes over time."""

        @property
        def auto(self) -> global___ComputeSpec.ScalePolicy.AutoScale:
            """Scale policy that can adjust number of running exec nodes within specified range based on some criteria."""

        def __init__(
            self,
            *,
            fixed: global___ComputeSpec.ScalePolicy.FixedScale | None = ...,
            auto: global___ComputeSpec.ScalePolicy.AutoScale | None = ...,
        ) -> None: ...
        def HasField(self, field_name: typing.Literal["auto", b"auto", "fixed", b"fixed", "policy", b"policy"]) -> builtins.bool: ...
        def ClearField(self, field_name: typing.Literal["auto", b"auto", "fixed", b"fixed", "policy", b"policy"]) -> None: ...
        def WhichOneof(self, oneof_group: typing.Literal["policy", b"policy"]) -> typing.Literal["fixed", "auto"] | None: ...

    PRESET_FIELD_NUMBER: builtins.int
    DISKS_FIELD_NUMBER: builtins.int
    SCALE_POLICY_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    preset: builtins.str
    """VM configuration preset name."""
    name: builtins.str
    """Name for exec pool."""
    @property
    def disks(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ComputeSpec.DiskSpec]:
        """Configuration of exec node strorage."""

    @property
    def scale_policy(self) -> global___ComputeSpec.ScalePolicy:
        """Exec nodes scaling policy."""

    def __init__(
        self,
        *,
        preset: builtins.str = ...,
        disks: collections.abc.Iterable[global___ComputeSpec.DiskSpec] | None = ...,
        scale_policy: global___ComputeSpec.ScalePolicy | None = ...,
        name: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["scale_policy", b"scale_policy"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["disks", b"disks", "name", b"name", "preset", b"preset", "scale_policy", b"scale_policy"]) -> None: ...

global___ComputeSpec = ComputeSpec

@typing.final
class HttpProxySpec(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    COUNT_FIELD_NUMBER: builtins.int
    count: builtins.int
    """Total amount of HTTP proxies."""
    def __init__(
        self,
        *,
        count: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["count", b"count"]) -> None: ...

global___HttpProxySpec = HttpProxySpec

@typing.final
class RpcProxySpec(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    COUNT_FIELD_NUMBER: builtins.int
    count: builtins.int
    """Total amount of RPC proxies."""
    def __init__(
        self,
        *,
        count: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["count", b"count"]) -> None: ...

global___RpcProxySpec = RpcProxySpec

@typing.final
class TabletSpec(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PRESET_FIELD_NUMBER: builtins.int
    COUNT_FIELD_NUMBER: builtins.int
    preset: builtins.str
    """VM configuration preset name."""
    count: builtins.int
    """Total amount of tablet nodes."""
    def __init__(
        self,
        *,
        preset: builtins.str = ...,
        count: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["count", b"count", "preset", b"preset"]) -> None: ...

global___TabletSpec = TabletSpec

@typing.final
class TaskProxySpec(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    COUNT_FIELD_NUMBER: builtins.int
    count: builtins.int
    """Total amount of task proxies."""
    def __init__(
        self,
        *,
        count: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["count", b"count"]) -> None: ...

global___TaskProxySpec = TaskProxySpec

@typing.final
class ProxySpec(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    HTTP_FIELD_NUMBER: builtins.int
    RPC_FIELD_NUMBER: builtins.int
    TASK_FIELD_NUMBER: builtins.int
    @property
    def http(self) -> global___HttpProxySpec:
        """Configuration of HTTP proxies."""

    @property
    def rpc(self) -> global___RpcProxySpec:
        """Configuration of rpc proxies."""

    @property
    def task(self) -> global___TaskProxySpec:
        """Configuration of task proxies."""

    def __init__(
        self,
        *,
        http: global___HttpProxySpec | None = ...,
        rpc: global___RpcProxySpec | None = ...,
        task: global___TaskProxySpec | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["http", b"http", "rpc", b"rpc", "task", b"task"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["http", b"http", "rpc", b"rpc", "task", b"task"]) -> None: ...

global___ProxySpec = ProxySpec

@typing.final
class OdinSpec(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CHECKS_TTL_FIELD_NUMBER: builtins.int
    @property
    def checks_ttl(self) -> google.protobuf.duration_pb2.Duration:
        """TTL of Odin check samples."""

    def __init__(
        self,
        *,
        checks_ttl: google.protobuf.duration_pb2.Duration | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["checks_ttl", b"checks_ttl"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["checks_ttl", b"checks_ttl"]) -> None: ...

global___OdinSpec = OdinSpec

@typing.final
class ClearTmpCronSpec(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INTERVAL_FIELD_NUMBER: builtins.int
    ACCOUNT_USAGE_RATIO_SAVE_TOTAL_FIELD_NUMBER: builtins.int
    ACCOUNT_USAGE_RATIO_SAVE_PER_OWNER_FIELD_NUMBER: builtins.int
    MAX_DIR_NODE_COUNT_FIELD_NUMBER: builtins.int
    account_usage_ratio_save_total: builtins.float
    """Total max space usage ratio."""
    account_usage_ratio_save_per_owner: builtins.float
    """Per account max space usage ratio."""
    max_dir_node_count: builtins.int
    """Max nodes in every directory."""
    @property
    def interval(self) -> google.protobuf.duration_pb2.Duration:
        """Script starting interval."""

    def __init__(
        self,
        *,
        interval: google.protobuf.duration_pb2.Duration | None = ...,
        account_usage_ratio_save_total: builtins.float = ...,
        account_usage_ratio_save_per_owner: builtins.float = ...,
        max_dir_node_count: builtins.int = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["interval", b"interval"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["account_usage_ratio_save_per_owner", b"account_usage_ratio_save_per_owner", "account_usage_ratio_save_total", b"account_usage_ratio_save_total", "interval", b"interval", "max_dir_node_count", b"max_dir_node_count"]) -> None: ...

global___ClearTmpCronSpec = ClearTmpCronSpec

@typing.final
class CronSpec(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CLEAR_TMP_FIELD_NUMBER: builtins.int
    @property
    def clear_tmp(self) -> global___ClearTmpCronSpec:
        """Cluster regular tmp-account cleaning settings."""

    def __init__(
        self,
        *,
        clear_tmp: global___ClearTmpCronSpec | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["clear_tmp", b"clear_tmp"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["clear_tmp", b"clear_tmp"]) -> None: ...

global___CronSpec = CronSpec

@typing.final
class ClientLogging(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SERVICE_ACCOUNT_ID_FIELD_NUMBER: builtins.int
    LOG_GROUP_ID_FIELD_NUMBER: builtins.int
    FOLDER_ID_FIELD_NUMBER: builtins.int
    AUDIT_LOGS_ENABLED_FIELD_NUMBER: builtins.int
    service_account_id: builtins.str
    """ID of Service account used for write logs."""
    log_group_id: builtins.str
    """ID of cloud logging group."""
    folder_id: builtins.str
    """ID of cloud logging folder. Used default loging group."""
    audit_logs_enabled: builtins.bool
    """Enable audit logs."""
    def __init__(
        self,
        *,
        service_account_id: builtins.str = ...,
        log_group_id: builtins.str = ...,
        folder_id: builtins.str = ...,
        audit_logs_enabled: builtins.bool = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["destination", b"destination", "folder_id", b"folder_id", "log_group_id", b"log_group_id"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["audit_logs_enabled", b"audit_logs_enabled", "destination", b"destination", "folder_id", b"folder_id", "log_group_id", b"log_group_id", "service_account_id", b"service_account_id"]) -> None: ...
    def WhichOneof(self, oneof_group: typing.Literal["destination", b"destination"]) -> typing.Literal["log_group_id", "folder_id"] | None: ...

global___ClientLogging = ClientLogging

@typing.final
class ExcelSpec(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ENABLED_FIELD_NUMBER: builtins.int
    enabled: builtins.bool
    """Enable Excel."""
    def __init__(
        self,
        *,
        enabled: builtins.bool = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["enabled", b"enabled"]) -> None: ...

global___ExcelSpec = ExcelSpec

@typing.final
class ClusterSpec(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    class _Flavor:
        ValueType = typing.NewType("ValueType", builtins.int)
        V: typing_extensions.TypeAlias = ValueType

    class _FlavorEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[ClusterSpec._Flavor.ValueType], builtins.type):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
        FLAVOR_UNSPECIFIED: ClusterSpec._Flavor.ValueType  # 0
        """Unspecified flavor."""
        DEMO: ClusterSpec._Flavor.ValueType  # 1
        """Demo cluster configuration with minimal system resources. Not fault-tolerant, not for production use."""

    class Flavor(_Flavor, metaclass=_FlavorEnumTypeWrapper): ...
    FLAVOR_UNSPECIFIED: ClusterSpec.Flavor.ValueType  # 0
    """Unspecified flavor."""
    DEMO: ClusterSpec.Flavor.ValueType  # 1
    """Demo cluster configuration with minimal system resources. Not fault-tolerant, not for production use."""

    STORAGE_FIELD_NUMBER: builtins.int
    COMPUTE_FIELD_NUMBER: builtins.int
    TABLET_FIELD_NUMBER: builtins.int
    PROXY_FIELD_NUMBER: builtins.int
    ODIN_FIELD_NUMBER: builtins.int
    FLAVOR_FIELD_NUMBER: builtins.int
    CRON_FIELD_NUMBER: builtins.int
    CLIENT_LOGGING_FIELD_NUMBER: builtins.int
    EXCEL_FIELD_NUMBER: builtins.int
    flavor: global___ClusterSpec.Flavor.ValueType
    """Cluster flavor (type)."""
    @property
    def storage(self) -> global___StorageSpec:
        """Cluster storage configuration."""

    @property
    def compute(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ComputeSpec]:
        """Cluster exec nodes configuration."""

    @property
    def tablet(self) -> global___TabletSpec:
        """Cluster tablet nodes configuration."""

    @property
    def proxy(self) -> global___ProxySpec:
        """Cluster proxies configuration."""

    @property
    def odin(self) -> global___OdinSpec:
        """Odin configuration."""

    @property
    def cron(self) -> global___CronSpec:
        """Cluster regular processing settings."""

    @property
    def client_logging(self) -> global___ClientLogging:
        """Client Cloud logging configuration."""

    @property
    def excel(self) -> global___ExcelSpec:
        """Cluster Excel configuration."""

    def __init__(
        self,
        *,
        storage: global___StorageSpec | None = ...,
        compute: collections.abc.Iterable[global___ComputeSpec] | None = ...,
        tablet: global___TabletSpec | None = ...,
        proxy: global___ProxySpec | None = ...,
        odin: global___OdinSpec | None = ...,
        flavor: global___ClusterSpec.Flavor.ValueType = ...,
        cron: global___CronSpec | None = ...,
        client_logging: global___ClientLogging | None = ...,
        excel: global___ExcelSpec | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["client_logging", b"client_logging", "cron", b"cron", "excel", b"excel", "odin", b"odin", "proxy", b"proxy", "storage", b"storage", "tablet", b"tablet"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["client_logging", b"client_logging", "compute", b"compute", "cron", b"cron", "excel", b"excel", "flavor", b"flavor", "odin", b"odin", "proxy", b"proxy", "storage", b"storage", "tablet", b"tablet"]) -> None: ...

global___ClusterSpec = ClusterSpec



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: yandex/cloud/iam/v1/awscompatibility/temporary_access_key_service.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'yandex/cloud/iam/v1/awscompatibility/temporary_access_key_service.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from yandex.cloud import validation_pb2 as yandex_dot_cloud_dot_validation__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nGyandex/cloud/iam/v1/awscompatibility/temporary_access_key_service.proto\x12$yandex.cloud.iam.v1.awscompatibility\x1a\x1cgoogle/api/annotations.proto\x1a\x1egoogle/protobuf/duration.proto\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x1dyandex/cloud/validation.proto\"\xb7\x01\n\x1f\x43reateEphemeralAccessKeyRequest\x12\x1c\n\nsubject_id\x18\x01 \x01(\tB\x08\x8a\xc8\x31\x04<=50\x12\"\n\x0csession_name\x18\x02 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04\x31-64\x12\x1a\n\x06policy\x18\x03 \x01(\tB\n\x8a\xc8\x31\x06<=2048\x12\x36\n\x08\x64uration\x18\x04 \x01(\x0b\x32\x19.google.protobuf.DurationB\t\xfa\xc7\x31\x05>=15m\"\x90\x01\n CreateEphemeralAccessKeyResponse\x12\x15\n\raccess_key_id\x18\x01 \x01(\t\x12\x0e\n\x06secret\x18\x02 \x01(\t\x12\x15\n\rsession_token\x18\x03 \x01(\t\x12.\n\nexpires_at\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.Timestamp2\xf8\x01\n\x19TemporaryAccessKeyService\x12\xda\x01\n\x0f\x43reateEphemeral\x12\x45.yandex.cloud.iam.v1.awscompatibility.CreateEphemeralAccessKeyRequest\x1a\x46.yandex.cloud.iam.v1.awscompatibility.CreateEphemeralAccessKeyResponse\"8\x82\xd3\xe4\x93\x02\x32\"-/iam/aws-compatibility/v1/ephemeralAccessKeys:\x01*B\x85\x01\n(yandex.cloud.api.iam.v1.awscompatibilityZYgithub.com/yandex-cloud/go-genproto/yandex/cloud/iam/v1/awscompatibility;awscompatibilityb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.iam.v1.awscompatibility.temporary_access_key_service_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n(yandex.cloud.api.iam.v1.awscompatibilityZYgithub.com/yandex-cloud/go-genproto/yandex/cloud/iam/v1/awscompatibility;awscompatibility'
  _globals['_CREATEEPHEMERALACCESSKEYREQUEST'].fields_by_name['subject_id']._loaded_options = None
  _globals['_CREATEEPHEMERALACCESSKEYREQUEST'].fields_by_name['subject_id']._serialized_options = b'\212\3101\004<=50'
  _globals['_CREATEEPHEMERALACCESSKEYREQUEST'].fields_by_name['session_name']._loaded_options = None
  _globals['_CREATEEPHEMERALACCESSKEYREQUEST'].fields_by_name['session_name']._serialized_options = b'\350\3071\001\212\3101\0041-64'
  _globals['_CREATEEPHEMERALACCESSKEYREQUEST'].fields_by_name['policy']._loaded_options = None
  _globals['_CREATEEPHEMERALACCESSKEYREQUEST'].fields_by_name['policy']._serialized_options = b'\212\3101\006<=2048'
  _globals['_CREATEEPHEMERALACCESSKEYREQUEST'].fields_by_name['duration']._loaded_options = None
  _globals['_CREATEEPHEMERALACCESSKEYREQUEST'].fields_by_name['duration']._serialized_options = b'\372\3071\005>=15m'
  _globals['_TEMPORARYACCESSKEYSERVICE'].methods_by_name['CreateEphemeral']._loaded_options = None
  _globals['_TEMPORARYACCESSKEYSERVICE'].methods_by_name['CreateEphemeral']._serialized_options = b'\202\323\344\223\0022\"-/iam/aws-compatibility/v1/ephemeralAccessKeys:\001*'
  _globals['_CREATEEPHEMERALACCESSKEYREQUEST']._serialized_start=240
  _globals['_CREATEEPHEMERALACCESSKEYREQUEST']._serialized_end=423
  _globals['_CREATEEPHEMERALACCESSKEYRESPONSE']._serialized_start=426
  _globals['_CREATEEPHEMERALACCESSKEYRESPONSE']._serialized_end=570
  _globals['_TEMPORARYACCESSKEYSERVICE']._serialized_start=573
  _globals['_TEMPORARYACCESSKEYSERVICE']._serialized_end=821
# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import typing

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class LabelList(google.protobuf.message.Message):
    """Represents a list of label values for filtering or grouping in usage reports.
    For example, to filter resources with label key "env" that have value "prod" or "test",
    a LabelList with values ["prod", "test"] would be used for the key "env".
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    VALUES_FIELD_NUMBER: builtins.int
    @property
    def values(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
        """List of label values associated with a specific label key."""

    def __init__(
        self,
        *,
        values: collections.abc.Iterable[builtins.str] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["values", b"values"]) -> None: ...

global___LabelList = LabelList

@typing.final
class BillingAccount(google.protobuf.message.Message):
    """Represents a billing account entity"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ID_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    id: builtins.str
    """Unique identifier of the billing_account entity."""
    name: builtins.str
    """Human-readable display name of the billing account."""
    def __init__(
        self,
        *,
        id: builtins.str = ...,
        name: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["id", b"id", "name", b"name"]) -> None: ...

global___BillingAccount = BillingAccount

@typing.final
class Cloud(google.protobuf.message.Message):
    """Represents a cloud entity"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ID_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    id: builtins.str
    """Unique identifier of the cloud entity."""
    name: builtins.str
    """Human-readable display name of the cloud."""
    def __init__(
        self,
        *,
        id: builtins.str = ...,
        name: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["id", b"id", "name", b"name"]) -> None: ...

global___Cloud = Cloud

@typing.final
class Folder(google.protobuf.message.Message):
    """Represents a folder entity"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ID_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    id: builtins.str
    """Unique identifier of the folder entity."""
    name: builtins.str
    """Human-readable display name of the folder."""
    def __init__(
        self,
        *,
        id: builtins.str = ...,
        name: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["id", b"id", "name", b"name"]) -> None: ...

global___Folder = Folder

@typing.final
class Service(google.protobuf.message.Message):
    """Represents a service entity"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ID_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    id: builtins.str
    """Unique identifier of the service entity."""
    name: builtins.str
    """Service display name."""
    description: builtins.str
    """Service description."""
    def __init__(
        self,
        *,
        id: builtins.str = ...,
        name: builtins.str = ...,
        description: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["description", b"description", "id", b"id", "name", b"name"]) -> None: ...

global___Service = Service

@typing.final
class SKU(google.protobuf.message.Message):
    """Represents a SKU (Stock Keeping Unit)"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ID_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    RU_TRANSLATION_FIELD_NUMBER: builtins.int
    EN_TRANSLATION_FIELD_NUMBER: builtins.int
    PRICING_UNIT_FIELD_NUMBER: builtins.int
    SERVICE_ID_FIELD_NUMBER: builtins.int
    id: builtins.str
    """Unique identifier of the entity (SKU)."""
    name: builtins.str
    """Product (SKU) name."""
    ru_translation: builtins.str
    """Russian-language display name"""
    en_translation: builtins.str
    """English-language display name"""
    pricing_unit: builtins.str
    """Unit of measurement for pricing (e.g., "hour", "byte", "1m*request")."""
    service_id: builtins.str
    """The service ID this SKU belongs to;"""
    def __init__(
        self,
        *,
        id: builtins.str = ...,
        name: builtins.str = ...,
        ru_translation: builtins.str = ...,
        en_translation: builtins.str = ...,
        pricing_unit: builtins.str = ...,
        service_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["en_translation", b"en_translation", "id", b"id", "name", b"name", "pricing_unit", b"pricing_unit", "ru_translation", b"ru_translation", "service_id", b"service_id"]) -> None: ...

global___SKU = SKU

@typing.final
class Resource(google.protobuf.message.Message):
    """Represents a resource entity"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ID_FIELD_NUMBER: builtins.int
    id: builtins.str
    """Unique identifier of the resource entity."""
    def __init__(
        self,
        *,
        id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["id", b"id"]) -> None: ...

global___Resource = Resource

@typing.final
class Label(google.protobuf.message.Message):
    """Represents a key-value label pair attached to resources for custom metadata tagging.
    Labels allow grouping and filtering resources by user-defined dimensions.
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    KEY_FIELD_NUMBER: builtins.int
    VALUE_FIELD_NUMBER: builtins.int
    key: builtins.str
    """Label key (e.g., "region", "environment", "team", "project")."""
    value: builtins.str
    """The label value (e.g., "usa", "mexico", "prod", "test", "finance", "backend")"""
    def __init__(
        self,
        *,
        key: builtins.str = ...,
        value: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["key", b"key", "value", b"value"]) -> None: ...

global___Label = Label



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import google.protobuf.timestamp_pb2
import google.protobuf.wrappers_pb2
import sys
import typing

if sys.version_info >= (3, 10):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class _GroupDistributionType:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _GroupDistributionTypeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_GroupDistributionType.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    GROUP_DISTRIBUTION_TYPE_UNSPECIFIED: _GroupDistributionType.ValueType  # 0
    """The group distribution type is not specified."""
    NONE: _GroupDistributionType.ValueType  # 1
    """No groups are provided to the application."""
    ASSIGNED_GROUPS: _GroupDistributionType.ValueType  # 2
    """Only assigned groups are provided to the application."""
    ALL_GROUPS: _GroupDistributionType.ValueType  # 3
    """All groups are provided to the application."""

class GroupDistributionType(_GroupDistributionType, metaclass=_GroupDistributionTypeEnumTypeWrapper):
    """Group distribution types for SAML applications."""

GROUP_DISTRIBUTION_TYPE_UNSPECIFIED: GroupDistributionType.ValueType  # 0
"""The group distribution type is not specified."""
NONE: GroupDistributionType.ValueType  # 1
"""No groups are provided to the application."""
ASSIGNED_GROUPS: GroupDistributionType.ValueType  # 2
"""Only assigned groups are provided to the application."""
ALL_GROUPS: GroupDistributionType.ValueType  # 3
"""All groups are provided to the application."""
global___GroupDistributionType = GroupDistributionType

@typing.final
class Application(google.protobuf.message.Message):
    """A SAML application resource."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    class _Status:
        ValueType = typing.NewType("ValueType", builtins.int)
        V: typing_extensions.TypeAlias = ValueType

    class _StatusEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[Application._Status.ValueType], builtins.type):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
        STATUS_UNSPECIFIED: Application._Status.ValueType  # 0
        """The status is not specified."""
        CREATING: Application._Status.ValueType  # 1
        """The application is in the process of being created."""
        ACTIVE: Application._Status.ValueType  # 2
        """The application is active and can be used for authentication."""
        SUSPENDED: Application._Status.ValueType  # 3
        """The application is suspended. I.e. authentication via this application is disabled."""
        DELETING: Application._Status.ValueType  # 4
        """The application is in the process of being deleted."""

    class Status(_Status, metaclass=_StatusEnumTypeWrapper):
        """Represents the status of a SAML application."""

    STATUS_UNSPECIFIED: Application.Status.ValueType  # 0
    """The status is not specified."""
    CREATING: Application.Status.ValueType  # 1
    """The application is in the process of being created."""
    ACTIVE: Application.Status.ValueType  # 2
    """The application is active and can be used for authentication."""
    SUSPENDED: Application.Status.ValueType  # 3
    """The application is suspended. I.e. authentication via this application is disabled."""
    DELETING: Application.Status.ValueType  # 4
    """The application is in the process of being deleted."""

    @typing.final
    class LabelsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing.Literal["key", b"key", "value", b"value"]) -> None: ...

    ID_FIELD_NUMBER: builtins.int
    ORGANIZATION_ID_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    STATUS_FIELD_NUMBER: builtins.int
    LABELS_FIELD_NUMBER: builtins.int
    CREATED_AT_FIELD_NUMBER: builtins.int
    UPDATED_AT_FIELD_NUMBER: builtins.int
    SERVICE_PROVIDER_FIELD_NUMBER: builtins.int
    SECURITY_SETTINGS_FIELD_NUMBER: builtins.int
    ATTRIBUTE_MAPPING_FIELD_NUMBER: builtins.int
    GROUP_CLAIMS_SETTINGS_FIELD_NUMBER: builtins.int
    IDENTITY_PROVIDER_METADATA_FIELD_NUMBER: builtins.int
    id: builtins.str
    """Unique identifier of the SAML application."""
    organization_id: builtins.str
    """ID of the organization that the application belongs to."""
    name: builtins.str
    """Name of the SAML application."""
    description: builtins.str
    """Description of the SAML application."""
    status: global___Application.Status.ValueType
    """Current status of the SAML application."""
    @property
    def labels(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]:
        """Resource labels as `` key:value `` pairs."""

    @property
    def created_at(self) -> google.protobuf.timestamp_pb2.Timestamp:
        """Creation timestamp."""

    @property
    def updated_at(self) -> google.protobuf.timestamp_pb2.Timestamp:
        """Modification timestamp."""

    @property
    def service_provider(self) -> global___ServiceProvider:
        """Service provider configuration for the SAML application."""

    @property
    def security_settings(self) -> global___SecuritySettings:
        """Security settings for the SAML application."""

    @property
    def attribute_mapping(self) -> global___AttributeMapping:
        """Attribute mapping configuration for the SAML application."""

    @property
    def group_claims_settings(self) -> global___GroupClaimsSettings:
        """Group claims settings for the SAML application."""

    @property
    def identity_provider_metadata(self) -> global___IdentityProviderMetadata:
        """Identity provider metadata for the SAML application."""

    def __init__(
        self,
        *,
        id: builtins.str = ...,
        organization_id: builtins.str = ...,
        name: builtins.str = ...,
        description: builtins.str = ...,
        status: global___Application.Status.ValueType = ...,
        labels: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        created_at: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        updated_at: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        service_provider: global___ServiceProvider | None = ...,
        security_settings: global___SecuritySettings | None = ...,
        attribute_mapping: global___AttributeMapping | None = ...,
        group_claims_settings: global___GroupClaimsSettings | None = ...,
        identity_provider_metadata: global___IdentityProviderMetadata | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["attribute_mapping", b"attribute_mapping", "created_at", b"created_at", "group_claims_settings", b"group_claims_settings", "identity_provider_metadata", b"identity_provider_metadata", "security_settings", b"security_settings", "service_provider", b"service_provider", "updated_at", b"updated_at"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["attribute_mapping", b"attribute_mapping", "created_at", b"created_at", "description", b"description", "group_claims_settings", b"group_claims_settings", "id", b"id", "identity_provider_metadata", b"identity_provider_metadata", "labels", b"labels", "name", b"name", "organization_id", b"organization_id", "security_settings", b"security_settings", "service_provider", b"service_provider", "status", b"status", "updated_at", b"updated_at"]) -> None: ...

global___Application = Application

@typing.final
class IdentityProviderMetadata(google.protobuf.message.Message):
    """Identity provider metadata for SAML applications."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ISSUER_FIELD_NUMBER: builtins.int
    SSO_URL_FIELD_NUMBER: builtins.int
    METADATA_URL_FIELD_NUMBER: builtins.int
    SLO_URL_FIELD_NUMBER: builtins.int
    issuer: builtins.str
    """Identity provider issuer identifier."""
    sso_url: builtins.str
    """Identity provider Single Sign-On URL."""
    metadata_url: builtins.str
    """Identity provider metadata URL."""
    slo_url: builtins.str
    """Identity provider Single Logout URL."""
    def __init__(
        self,
        *,
        issuer: builtins.str = ...,
        sso_url: builtins.str = ...,
        metadata_url: builtins.str = ...,
        slo_url: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["issuer", b"issuer", "metadata_url", b"metadata_url", "slo_url", b"slo_url", "sso_url", b"sso_url"]) -> None: ...

global___IdentityProviderMetadata = IdentityProviderMetadata

@typing.final
class ServiceProvider(google.protobuf.message.Message):
    """Service provider configuration for SAML applications."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ENTITY_ID_FIELD_NUMBER: builtins.int
    ACS_URLS_FIELD_NUMBER: builtins.int
    SLO_URLS_FIELD_NUMBER: builtins.int
    entity_id: builtins.str
    """Service provider entity ID."""
    @property
    def acs_urls(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___AssertionConsumerServiceURL]:
        """Assertion Consumer Service URLs."""

    @property
    def slo_urls(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___SingleLogoutServiceURL]:
        """Single Logout Service URLs."""

    def __init__(
        self,
        *,
        entity_id: builtins.str = ...,
        acs_urls: collections.abc.Iterable[global___AssertionConsumerServiceURL] | None = ...,
        slo_urls: collections.abc.Iterable[global___SingleLogoutServiceURL] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["acs_urls", b"acs_urls", "entity_id", b"entity_id", "slo_urls", b"slo_urls"]) -> None: ...

global___ServiceProvider = ServiceProvider

@typing.final
class AssertionConsumerServiceURL(google.protobuf.message.Message):
    """Assertion Consumer Service URL configuration."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    URL_FIELD_NUMBER: builtins.int
    INDEX_FIELD_NUMBER: builtins.int
    url: builtins.str
    """The URL where SAML responses are sent."""
    @property
    def index(self) -> google.protobuf.wrappers_pb2.Int64Value:
        """Optional index for the assertion consumer service."""

    def __init__(
        self,
        *,
        url: builtins.str = ...,
        index: google.protobuf.wrappers_pb2.Int64Value | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["index", b"index"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["index", b"index", "url", b"url"]) -> None: ...

global___AssertionConsumerServiceURL = AssertionConsumerServiceURL

@typing.final
class SingleLogoutServiceURL(google.protobuf.message.Message):
    """Single Logout Service URL configuration."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    class _ProtocolBinding:
        ValueType = typing.NewType("ValueType", builtins.int)
        V: typing_extensions.TypeAlias = ValueType

    class _ProtocolBindingEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[SingleLogoutServiceURL._ProtocolBinding.ValueType], builtins.type):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
        PROTOCOL_BINDING_UNSPECIFIED: SingleLogoutServiceURL._ProtocolBinding.ValueType  # 0
        """The protocol binding is not specified."""
        HTTP_POST: SingleLogoutServiceURL._ProtocolBinding.ValueType  # 1
        """HTTP POST binding."""
        HTTP_REDIRECT: SingleLogoutServiceURL._ProtocolBinding.ValueType  # 2
        """HTTP Redirect binding."""

    class ProtocolBinding(_ProtocolBinding, metaclass=_ProtocolBindingEnumTypeWrapper):
        """Protocol bindings supported by the logout endpoint."""

    PROTOCOL_BINDING_UNSPECIFIED: SingleLogoutServiceURL.ProtocolBinding.ValueType  # 0
    """The protocol binding is not specified."""
    HTTP_POST: SingleLogoutServiceURL.ProtocolBinding.ValueType  # 1
    """HTTP POST binding."""
    HTTP_REDIRECT: SingleLogoutServiceURL.ProtocolBinding.ValueType  # 2
    """HTTP Redirect binding."""

    URL_FIELD_NUMBER: builtins.int
    RESPONSE_URL_FIELD_NUMBER: builtins.int
    PROTOCOL_BINDING_FIELD_NUMBER: builtins.int
    url: builtins.str
    """The URL where logout requests are sent."""
    response_url: builtins.str
    """Optional separate URL for logout responses."""
    protocol_binding: global___SingleLogoutServiceURL.ProtocolBinding.ValueType
    """Protocol binding supported by the logout endpoint."""
    def __init__(
        self,
        *,
        url: builtins.str = ...,
        response_url: builtins.str = ...,
        protocol_binding: global___SingleLogoutServiceURL.ProtocolBinding.ValueType = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["protocol_binding", b"protocol_binding", "response_url", b"response_url", "url", b"url"]) -> None: ...

global___SingleLogoutServiceURL = SingleLogoutServiceURL

@typing.final
class SecuritySettings(google.protobuf.message.Message):
    """Security settings for SAML applications."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    class _SignatureMode:
        ValueType = typing.NewType("ValueType", builtins.int)
        V: typing_extensions.TypeAlias = ValueType

    class _SignatureModeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[SecuritySettings._SignatureMode.ValueType], builtins.type):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
        SIGNATURE_MODE_UNSPECIFIED: SecuritySettings._SignatureMode.ValueType  # 0
        """The signature mode is not specified."""
        ASSERTIONS: SecuritySettings._SignatureMode.ValueType  # 1
        """Sign individual assertions."""
        RESPONSE: SecuritySettings._SignatureMode.ValueType  # 2
        """Sign the entire response."""
        RESPONSE_AND_ASSERTIONS: SecuritySettings._SignatureMode.ValueType  # 3
        """Sign both the response and individual assertions."""

    class SignatureMode(_SignatureMode, metaclass=_SignatureModeEnumTypeWrapper):
        """Signature modes for SAML messages."""

    SIGNATURE_MODE_UNSPECIFIED: SecuritySettings.SignatureMode.ValueType  # 0
    """The signature mode is not specified."""
    ASSERTIONS: SecuritySettings.SignatureMode.ValueType  # 1
    """Sign individual assertions."""
    RESPONSE: SecuritySettings.SignatureMode.ValueType  # 2
    """Sign the entire response."""
    RESPONSE_AND_ASSERTIONS: SecuritySettings.SignatureMode.ValueType  # 3
    """Sign both the response and individual assertions."""

    SIGNATURE_MODE_FIELD_NUMBER: builtins.int
    SIGNATURE_CERTIFICATE_ID_FIELD_NUMBER: builtins.int
    signature_mode: global___SecuritySettings.SignatureMode.ValueType
    """Signature mode for SAML messages."""
    signature_certificate_id: builtins.str
    """ID of the signature certificate to use."""
    def __init__(
        self,
        *,
        signature_mode: global___SecuritySettings.SignatureMode.ValueType = ...,
        signature_certificate_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["signature_certificate_id", b"signature_certificate_id", "signature_mode", b"signature_mode"]) -> None: ...

global___SecuritySettings = SecuritySettings

@typing.final
class AttributeMapping(google.protobuf.message.Message):
    """Attribute mapping configuration for SAML applications."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAME_ID_FIELD_NUMBER: builtins.int
    ATTRIBUTES_FIELD_NUMBER: builtins.int
    @property
    def name_id(self) -> global___NameId:
        """NameID configuration for the SAML application."""

    @property
    def attributes(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___Attribute]:
        """List of attribute mappings."""

    def __init__(
        self,
        *,
        name_id: global___NameId | None = ...,
        attributes: collections.abc.Iterable[global___Attribute] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["name_id", b"name_id"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["attributes", b"attributes", "name_id", b"name_id"]) -> None: ...

global___AttributeMapping = AttributeMapping

@typing.final
class NameId(google.protobuf.message.Message):
    """NameID configuration for SAML applications."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    class _Format:
        ValueType = typing.NewType("ValueType", builtins.int)
        V: typing_extensions.TypeAlias = ValueType

    class _FormatEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[NameId._Format.ValueType], builtins.type):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
        FORMAT_UNSPECIFIED: NameId._Format.ValueType  # 0
        """The NameID format is not specified."""
        PERSISTENT: NameId._Format.ValueType  # 1
        """Persistent NameID format.
        This provides a stable, opaque identifier for the user.
        """
        EMAIL: NameId._Format.ValueType  # 2
        """Email NameID format.
        This uses the user's email address as the identifier.
        """

    class Format(_Format, metaclass=_FormatEnumTypeWrapper):
        """NameID formats supported by SAML."""

    FORMAT_UNSPECIFIED: NameId.Format.ValueType  # 0
    """The NameID format is not specified."""
    PERSISTENT: NameId.Format.ValueType  # 1
    """Persistent NameID format.
    This provides a stable, opaque identifier for the user.
    """
    EMAIL: NameId.Format.ValueType  # 2
    """Email NameID format.
    This uses the user's email address as the identifier.
    """

    FORMAT_FIELD_NUMBER: builtins.int
    VALUE_FIELD_NUMBER: builtins.int
    format: global___NameId.Format.ValueType
    """Format of the NameID."""
    value: builtins.str
    """Value of the NameID."""
    def __init__(
        self,
        *,
        format: global___NameId.Format.ValueType = ...,
        value: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["format", b"format", "value", b"value"]) -> None: ...

global___NameId = NameId

@typing.final
class Attribute(google.protobuf.message.Message):
    """Attribute mapping for SAML applications."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAME_FIELD_NUMBER: builtins.int
    VALUE_FIELD_NUMBER: builtins.int
    name: builtins.str
    """Name of the SAML attribute."""
    value: builtins.str
    """Value of the SAML attribute."""
    def __init__(
        self,
        *,
        name: builtins.str = ...,
        value: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["name", b"name", "value", b"value"]) -> None: ...

global___Attribute = Attribute

@typing.final
class GroupClaimsSettings(google.protobuf.message.Message):
    """Group claims settings for SAML applications."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    GROUP_DISTRIBUTION_TYPE_FIELD_NUMBER: builtins.int
    GROUP_ATTRIBUTE_NAME_FIELD_NUMBER: builtins.int
    group_distribution_type: global___GroupDistributionType.ValueType
    """Distribution type for group claims."""
    group_attribute_name: builtins.str
    """Name of the SAML attribute that contains group information."""
    def __init__(
        self,
        *,
        group_distribution_type: global___GroupDistributionType.ValueType = ...,
        group_attribute_name: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["group_attribute_name", b"group_attribute_name", "group_distribution_type", b"group_distribution_type"]) -> None: ...

global___GroupClaimsSettings = GroupClaimsSettings



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import google.protobuf.descriptor
import google.protobuf.message
import google.protobuf.wrappers_pb2
import typing

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class OpenSearchConfig2(google.protobuf.message.Message):
    """OpenSearch server configuration settings."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    MAX_CLAUSE_COUNT_FIELD_NUMBER: builtins.int
    FIELDDATA_CACHE_SIZE_FIELD_NUMBER: builtins.int
    SEARCH_MAX_BUCKETS_FIELD_NUMBER: builtins.int
    REINDEX_REMOTE_WHITELIST_FIELD_NUMBER: builtins.int
    HTTP_MAX_INITIAL_LINE_LENGTH_FIELD_NUMBER: builtins.int
    fielddata_cache_size: builtins.str
    """The maximum size of the field data cache.
    May be specified as an absolute value (for example, 8GB) or a percentage of the node heap (for example, 50%).
    This setting is dynamic. If you don't specify this setting, the maximum size is 35%.
    This value should be smaller than the **indices.breaker.fielddata.limit**

    Change of the setting is applied with restart.

    For details, see [OpenSearch documentation](https://docs.opensearch.org/latest/install-and-configure/configuring-opensearch/index-settings/#dynamic-cluster-level-index-settings).
    """
    reindex_remote_whitelist: builtins.str
    """Allowed remote hosts

    Change of the setting is applied with restart.

    For details, see [OpenSearch documentation](https://docs.opensearch.org/latest/api-reference/document-apis/reindex/#remote-cluster-allow-list).
    """
    @property
    def max_clause_count(self) -> google.protobuf.wrappers_pb2.Int64Value:
        """Defines the maximum product of fields and terms that are queryable simultaneously.
        Before OpenSearch 2.16, a cluster restart was required in order to apply this static setting.
        Now dynamic, existing search thread pools may use the old static value initially, causing **TooManyClauses** exceptions.
        New thread pools use the updated value.

        Default value: **1024**.

        Change of the setting is applied with restart.

        For details, see [OpenSearch documentation](https://docs.opensearch.org/latest/install-and-configure/configuring-opensearch/index-settings/#dynamic-cluster-level-index-settings).
        """

    @property
    def search_max_buckets(self) -> google.protobuf.wrappers_pb2.Int64Value:
        """The maximum number of aggregation buckets allowed in a single response. Default is 65535

        Default value: **65535**.

        Change of the setting is applied with restart.

        For details, see [OpenSearch documentation](https://docs.opensearch.org/latest/install-and-configure/configuring-opensearch/search-settings).
        """

    @property
    def http_max_initial_line_length(self) -> google.protobuf.wrappers_pb2.StringValue:
        """Sets the maximum length allowed for HTTP URLs in the initial request line. URLs exceeding this limit will be rejected. Default is **4kb**.

        Default value: **4kb**.

        Change of the setting is applied with restart.

        For details, see [OpenSearch documentation](https://docs.opensearch.org/latest/install-and-configure/configuring-opensearch/network-settings/#advanced-http-settings).
        """

    def __init__(
        self,
        *,
        max_clause_count: google.protobuf.wrappers_pb2.Int64Value | None = ...,
        fielddata_cache_size: builtins.str = ...,
        search_max_buckets: google.protobuf.wrappers_pb2.Int64Value | None = ...,
        reindex_remote_whitelist: builtins.str = ...,
        http_max_initial_line_length: google.protobuf.wrappers_pb2.StringValue | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["http_max_initial_line_length", b"http_max_initial_line_length", "max_clause_count", b"max_clause_count", "search_max_buckets", b"search_max_buckets"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["fielddata_cache_size", b"fielddata_cache_size", "http_max_initial_line_length", b"http_max_initial_line_length", "max_clause_count", b"max_clause_count", "reindex_remote_whitelist", b"reindex_remote_whitelist", "search_max_buckets", b"search_max_buckets"]) -> None: ...

global___OpenSearchConfig2 = OpenSearchConfig2

@typing.final
class OpenSearchConfigSet2(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    EFFECTIVE_CONFIG_FIELD_NUMBER: builtins.int
    USER_CONFIG_FIELD_NUMBER: builtins.int
    DEFAULT_CONFIG_FIELD_NUMBER: builtins.int
    @property
    def effective_config(self) -> global___OpenSearchConfig2:
        """Effective configuration (a combination of user-defined configuration and default configuration)."""

    @property
    def user_config(self) -> global___OpenSearchConfig2:
        """User-defined configuration."""

    @property
    def default_config(self) -> global___OpenSearchConfig2:
        """Default configuration."""

    def __init__(
        self,
        *,
        effective_config: global___OpenSearchConfig2 | None = ...,
        user_config: global___OpenSearchConfig2 | None = ...,
        default_config: global___OpenSearchConfig2 | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["default_config", b"default_config", "effective_config", b"effective_config", "user_config", b"user_config"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["default_config", b"default_config", "effective_config", b"effective_config", "user_config", b"user_config"]) -> None: ...

global___OpenSearchConfigSet2 = OpenSearchConfigSet2
